@@ -1,5 +1,3 @@
-#!/usr/bin/python3
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -23,7 +21,7 @@ with atheris.instrument_imports():
     import fuzzers
 
 
-def TestOneInput(data):
+def TestOneInput(data: bytes) -> None:
     try:
         fuzzers.fuzz_image(data)
     except Exception:
@@ -32,7 +30,7 @@ def TestOneInput(data):
         pass
 
 
-def main():
+def main() -> None:
     fuzzers.enable_decompressionbomb_error()
     atheris.Setup(sys.argv, TestOneInput)
     atheris.Fuzz()
