@@ -1,5 +1,7 @@
 from __future__ import annotations
+
 from array import array
+from types import ModuleType
 
 import pytest
 
@@ -7,6 +9,7 @@ from PIL import Image, ImageFilter
 
 from .helper import assert_image_equal
 
+numpy: ModuleType | None
 try:
     import numpy
 except ImportError:
@@ -14,7 +17,9 @@ except ImportError:
 
 
 class TestColorLut3DCoreAPI:
-    def generate_identity_table(self, channels, size):
+    def generate_identity_table(
+        self, channels: int, size: int | tuple[int, int, int]
+    ) -> tuple[int, int, int, int, list[float]]:
         if isinstance(size, tuple):
             size_1d, size_2d, size_3d = size
         else:
@@ -40,7 +45,7 @@ class TestColorLut3DCoreAPI:
             [item for sublist in table for item in sublist],
         )
 
-    def test_wrong_args(self):
+    def test_wrong_args(self) -> None:
         im = Image.new("RGB", (10, 10), 0)
 
         with pytest.raises(ValueError, match="filter"):
@@ -100,7 +105,7 @@ class TestColorLut3DCoreAPI:
         with pytest.raises(TypeError):
             im.im.color_lut_3d("RGB", Image.Resampling.BILINEAR, 3, 2, 2, 2, 16)
 
-    def test_correct_args(self):
+    def test_correct_args(self) -> None:
         im = Image.new("RGB", (10, 10), 0)
 
         im.im.color_lut_3d(
@@ -135,7 +140,7 @@ class TestColorLut3DCoreAPI:
             *self.generate_identity_table(3, (3, 3, 65)),
         )
 
-    def test_wrong_mode(self):
+    def test_wrong_mode(self) -> None:
         with pytest.raises(ValueError, match="wrong mode"):
             im = Image.new("L", (10, 10), 0)
             im.im.color_lut_3d(
@@ -166,7 +171,7 @@ class TestColorLut3DCoreAPI:
                 "RGB", Image.Resampling.BILINEAR, *self.generate_identity_table(4, 3)
             )
 
-    def test_correct_mode(self):
+    def test_correct_mode(self) -> None:
         im = Image.new("RGBA", (10, 10), 0)
         im.im.color_lut_3d(
             "RGBA", Image.Resampling.BILINEAR, *self.generate_identity_table(3, 3)
@@ -187,7 +192,7 @@ class TestColorLut3DCoreAPI:
             "RGBA", Image.Resampling.BILINEAR, *self.generate_identity_table(4, 3)
         )
 
-    def test_identities(self):
+    def test_identities(self) -> None:
         g = Image.linear_gradient("L")
         im = Image.merge(
             "RGB",
@@ -223,7 +228,7 @@ class TestColorLut3DCoreAPI:
             ),
         )
 
-    def test_identities_4_channels(self):
+    def test_identities_4_channels(self) -> None:
         g = Image.linear_gradient("L")
         im = Image.merge(
             "RGB",
@@ -246,7 +251,7 @@ class TestColorLut3DCoreAPI:
             ),
         )
 
-    def test_copy_alpha_channel(self):
+    def test_copy_alpha_channel(self) -> None:
         g = Image.linear_gradient("L")
         im = Image.merge(
             "RGBA",
@@ -269,7 +274,7 @@ class TestColorLut3DCoreAPI:
             ),
         )
 
-    def test_channels_order(self):
+    def test_channels_order(self) -> None:
         g = Image.linear_gradient("L")
         im = Image.merge(
             "RGB",
@@ -294,7 +299,7 @@ class TestColorLut3DCoreAPI:
                     ])))
         # fmt: on
 
-    def test_overflow(self):
+    def test_overflow(self) -> None:
         g = Image.linear_gradient("L")
         im = Image.merge(
             "RGB",
@@ -347,12 +352,12 @@ class TestColorLut3DCoreAPI:
 
 
 class TestColorLut3DFilter:
-    def test_wrong_args(self):
+    def test_wrong_args(self) -> None:
         with pytest.raises(ValueError, match="should be either an integer"):
-            ImageFilter.Color3DLUT("small", [1])
+            ImageFilter.Color3DLUT("small", [1])  # type: ignore[arg-type]
 
         with pytest.raises(ValueError, match="should be either an integer"):
-            ImageFilter.Color3DLUT((11, 11), [1])
+            ImageFilter.Color3DLUT((11, 11), [1])  # type: ignore[arg-type]
 
         with pytest.raises(ValueError, match=r"in \[2, 65\] range"):
             ImageFilter.Color3DLUT((11, 11, 1), [1])
@@ -375,7 +380,7 @@ class TestColorLut3DFilter:
         with pytest.raises(ValueError, match="Only 3 or 4 output"):
             ImageFilter.Color3DLUT((2, 2, 2), [[1, 1]] * 8, channels=2)
 
-    def test_convert_table(self):
+    def test_convert_table(self) -> None:
         lut = ImageFilter.Color3DLUT(2, [0, 1, 2] * 8)
         assert tuple(lut.size) == (2, 2, 2)
         assert lut.name == "Color 3D LUT"
@@ -393,7 +398,8 @@ class TestColorLut3DFilter:
         assert lut.table == list(range(4)) * 8
 
     @pytest.mark.skipif(numpy is None, reason="NumPy not installed")
-    def test_numpy_sources(self):
+    def test_numpy_sources(self) -> None:
+        assert numpy is not None
         table = numpy.ones((5, 6, 7, 3), dtype=numpy.float16)
         with pytest.raises(ValueError, match="should have either channels"):
             lut = ImageFilter.Color3DLUT((5, 6, 7), table)
@@ -426,7 +432,8 @@ class TestColorLut3DFilter:
         assert lut.table[0] == 33
 
     @pytest.mark.skipif(numpy is None, reason="NumPy not installed")
-    def test_numpy_formats(self):
+    def test_numpy_formats(self) -> None:
+        assert numpy is not None
         g = Image.linear_gradient("L")
         im = Image.merge(
             "RGB",
@@ -465,7 +472,7 @@ class TestColorLut3DFilter:
         lut.table = numpy.array(lut.table, dtype=numpy.int8)
         im.filter(lut)
 
-    def test_repr(self):
+    def test_repr(self) -> None:
         lut = ImageFilter.Color3DLUT(2, [0, 1, 2] * 8)
         assert repr(lut) == "<Color3DLUT from list size=2x2x2 channels=3>"
 
@@ -483,7 +490,7 @@ class TestColorLut3DFilter:
 
 
 class TestGenerateColorLut3D:
-    def test_wrong_channels_count(self):
+    def test_wrong_channels_count(self) -> None:
         with pytest.raises(ValueError, match="3 or 4 output channels"):
             ImageFilter.Color3DLUT.generate(
                 5, channels=2, callback=lambda r, g, b: (r, g, b)
@@ -497,7 +504,7 @@ class TestGenerateColorLut3D:
                 5, channels=4, callback=lambda r, g, b: (r, g, b)
             )
 
-    def test_3_channels(self):
+    def test_3_channels(self) -> None:
         lut = ImageFilter.Color3DLUT.generate(5, lambda r, g, b: (r, g, b))
         assert tuple(lut.size) == (5, 5, 5)
         assert lut.name == "Color 3D LUT"
@@ -507,7 +514,7 @@ class TestGenerateColorLut3D:
             1.0, 0.0, 0.0,  0.0, 0.25, 0.0,  0.25, 0.25, 0.0,  0.5, 0.25, 0.0]
         # fmt: on
 
-    def test_4_channels(self):
+    def test_4_channels(self) -> None:
         lut = ImageFilter.Color3DLUT.generate(
             5, channels=4, callback=lambda r, g, b: (b, r, g, (r + g + b) / 2)
         )
@@ -520,7 +527,7 @@ class TestGenerateColorLut3D:
         ]
         # fmt: on
 
-    def test_apply(self):
+    def test_apply(self) -> None:
         lut = ImageFilter.Color3DLUT.generate(5, lambda r, g, b: (r, g, b))
 
         g = Image.linear_gradient("L")
@@ -536,7 +543,7 @@ class TestGenerateColorLut3D:
 
 
 class TestTransformColorLut3D:
-    def test_wrong_args(self):
+    def test_wrong_args(self) -> None:
         source = ImageFilter.Color3DLUT.generate(5, lambda r, g, b: (r, g, b))
 
         with pytest.raises(ValueError, match="Only 3 or 4 output"):
@@ -551,7 +558,7 @@ class TestTransformColorLut3D:
         with pytest.raises(TypeError):
             source.transform(lambda r, g, b, a: (r, g, b))
 
-    def test_target_mode(self):
+    def test_target_mode(self) -> None:
         source = ImageFilter.Color3DLUT.generate(
             2, lambda r, g, b: (r, g, b), target_mode="HSV"
         )
@@ -562,7 +569,7 @@ class TestTransformColorLut3D:
         lut = source.transform(lambda r, g, b: (r, g, b), target_mode="RGB")
         assert lut.mode == "RGB"
 
-    def test_3_to_3_channels(self):
+    def test_3_to_3_channels(self) -> None:
         source = ImageFilter.Color3DLUT.generate((3, 4, 5), lambda r, g, b: (r, g, b))
         lut = source.transform(lambda r, g, b: (r * r, g * g, b * b))
         assert tuple(lut.size) == tuple(source.size)
@@ -570,7 +577,7 @@ class TestTransformColorLut3D:
         assert lut.table != source.table
         assert lut.table[:10] == [0.0, 0.0, 0.0, 0.25, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0]
 
-    def test_3_to_4_channels(self):
+    def test_3_to_4_channels(self) -> None:
         source = ImageFilter.Color3DLUT.generate((6, 5, 4), lambda r, g, b: (r, g, b))
         lut = source.transform(lambda r, g, b: (r * r, g * g, b * b, 1), channels=4)
         assert tuple(lut.size) == tuple(source.size)
@@ -582,7 +589,7 @@ class TestTransformColorLut3D:
             0.4**2, 0.0, 0.0, 1,  0.6**2, 0.0, 0.0, 1]
         # fmt: on
 
-    def test_4_to_3_channels(self):
+    def test_4_to_3_channels(self) -> None:
         source = ImageFilter.Color3DLUT.generate(
             (3, 6, 5), lambda r, g, b: (r, g, b, 1), channels=4
         )
@@ -598,7 +605,7 @@ class TestTransformColorLut3D:
             1.0, 0.96, 1.0,  0.75, 0.96, 1.0,  0.0, 0.96, 1.0]
         # fmt: on
 
-    def test_4_to_4_channels(self):
+    def test_4_to_4_channels(self) -> None:
         source = ImageFilter.Color3DLUT.generate(
             (6, 5, 4), lambda r, g, b: (r, g, b, 1), channels=4
         )
@@ -612,7 +619,7 @@ class TestTransformColorLut3D:
             0.4**2, 0.0, 0.0, 0.5,  0.6**2, 0.0, 0.0, 0.5]
         # fmt: on
 
-    def test_with_normals_3_channels(self):
+    def test_with_normals_3_channels(self) -> None:
         source = ImageFilter.Color3DLUT.generate(
             (6, 5, 4), lambda r, g, b: (r * r, g * g, b * b)
         )
@@ -628,7 +635,7 @@ class TestTransformColorLut3D:
             0.24, 0.0, 0.0,  0.8 - (0.8**2), 0, 0,  0, 0, 0]
         # fmt: on
 
-    def test_with_normals_4_channels(self):
+    def test_with_normals_4_channels(self) -> None:
         source = ImageFilter.Color3DLUT.generate(
             (3, 6, 5), lambda r, g, b: (r * r, g * g, b * b, 1), channels=4
         )
