@@ -1,6 +1,9 @@
 from __future__ import annotations
+
 import warnings
 from io import BytesIO
+from pathlib import Path
+from typing import Generator
 
 import pytest
 
@@ -22,7 +25,7 @@ with open(TEST_GIF, "rb") as f:
     data = f.read()
 
 
-def test_sanity():
+def test_sanity() -> None:
     with Image.open(TEST_GIF) as im:
         im.load()
         assert im.mode == "P"
@@ -32,8 +35,8 @@ def test_sanity():
 
 
 @pytest.mark.skipif(is_pypy(), reason="Requires CPython")
-def test_unclosed_file():
-    def open():
+def test_unclosed_file() -> None:
+    def open() -> None:
         im = Image.open(TEST_GIF)
         im.load()
 
@@ -41,15 +44,16 @@ def test_unclosed_file():
         open()
 
 
-def test_closed_file():
+def test_closed_file() -> None:
     with warnings.catch_warnings():
         im = Image.open(TEST_GIF)
         im.load()
         im.close()
 
 
-def test_seek_after_close():
+def test_seek_after_close() -> None:
     im = Image.open("Tests/images/iss634.gif")
+    assert isinstance(im, GifImagePlugin.GifImageFile)
     im.load()
     im.close()
 
@@ -61,20 +65,20 @@ def test_seek_after_close():
         im.seek(1)
 
 
-def test_context_manager():
+def test_context_manager() -> None:
     with warnings.catch_warnings():
         with Image.open(TEST_GIF) as im:
             im.load()
 
 
-def test_invalid_file():
+def test_invalid_file() -> None:
     invalid_file = "Tests/images/flower.jpg"
 
     with pytest.raises(SyntaxError):
         GifImagePlugin.GifImageFile(invalid_file)
 
 
-def test_l_mode_transparency():
+def test_l_mode_transparency() -> None:
     with Image.open("Tests/images/no_palette_with_transparency.gif") as im:
         assert im.mode == "L"
         assert im.load()[0, 0] == 128
@@ -85,7 +89,7 @@ def test_l_mode_transparency():
         assert im.load()[0, 0] == 128
 
 
-def test_l_mode_after_rgb():
+def test_l_mode_after_rgb() -> None:
     with Image.open("Tests/images/no_palette_after_rgb.gif") as im:
         im.seek(1)
         assert im.mode == "RGB"
@@ -94,13 +98,13 @@ def test_l_mode_after_rgb():
         assert im.mode == "RGB"
 
 
-def test_palette_not_needed_for_second_frame():
+def test_palette_not_needed_for_second_frame() -> None:
     with Image.open("Tests/images/palette_not_needed_for_second_frame.gif") as im:
         im.seek(1)
         assert_image_similar(im, hopper("L").convert("RGB"), 8)
 
 
-def test_strategy():
+def test_strategy() -> None:
     with Image.open("Tests/images/iss634.gif") as im:
         expected_rgb_always = im.convert("RGB")
 
@@ -141,14 +145,14 @@ def test_strategy():
         GifImagePlugin.LOADING_STRATEGY = GifImagePlugin.LoadingStrategy.RGB_AFTER_FIRST
 
 
-def test_optimize():
-    def test_grayscale(optimize):
+def test_optimize() -> None:
+    def test_grayscale(optimize: int) -> int:
         im = Image.new("L", (1, 1), 0)
         filename = BytesIO()
         im.save(filename, "GIF", optimize=optimize)
         return len(filename.getvalue())
 
-    def test_bilevel(optimize):
+    def test_bilevel(optimize: int) -> int:
         im = Image.new("1", (1, 1), 0)
         test_file = BytesIO()
         im.save(test_file, "GIF", optimize=optimize)
@@ -176,7 +180,9 @@ def test_optimize():
         (4, 513, 256),
     ),
 )
-def test_optimize_correctness(colors, size, expected_palette_length):
+def test_optimize_correctness(
+    colors: int, size: int, expected_palette_length: int
+) -> None:
     # 256 color Palette image, posterize to > 128 and < 128 levels.
     # Size bigger and smaller than 512x512.
     # Check the palette for number of colors allocated.
@@ -198,14 +204,14 @@ def test_optimize_correctness(colors, size, expected_palette_length):
         assert_image_equal(im.convert("RGB"), reloaded.convert("RGB"))
 
 
-def test_optimize_full_l():
+def test_optimize_full_l() -> None:
     im = Image.frombytes("L", (16, 16), bytes(range(256)))
     test_file = BytesIO()
     im.save(test_file, "GIF", optimize=True)
     assert im.mode == "L"
 
 
-def test_optimize_if_palette_can_be_reduced_by_half():
+def test_optimize_if_palette_can_be_reduced_by_half() -> None:
     im = Image.new("P", (8, 1))
     im.palette = ImagePalette.raw("RGB", bytes((0, 0, 0) * 150))
     for i in range(8):
@@ -218,7 +224,7 @@ def test_optimize_if_palette_can_be_reduced_by_half():
             assert len(reloaded.palette.palette) // 3 == colors
 
 
-def test_full_palette_second_frame(tmp_path):
+def test_full_palette_second_frame(tmp_path: Path) -> None:
     out = str(tmp_path / "temp.gif")
     im = Image.new("P", (1, 256))
 
@@ -239,7 +245,7 @@ def test_full_palette_second_frame(tmp_path):
             reloaded.getpixel((0, i)) == i
 
 
-def test_roundtrip(tmp_path):
+def test_roundtrip(tmp_path: Path) -> None:
     out = str(tmp_path / "temp.gif")
     im = hopper()
     im.save(out)
@@ -247,7 +253,7 @@ def test_roundtrip(tmp_path):
         assert_image_similar(reread.convert("RGB"), im, 50)
 
 
-def test_roundtrip2(tmp_path):
+def test_roundtrip2(tmp_path: Path) -> None:
     # see https://github.com/python-pillow/Pillow/issues/403
     out = str(tmp_path / "temp.gif")
     with Image.open(TEST_GIF) as im:
@@ -257,7 +263,7 @@ def test_roundtrip2(tmp_path):
         assert_image_similar(reread.convert("RGB"), hopper(), 50)
 
 
-def test_roundtrip_save_all(tmp_path):
+def test_roundtrip_save_all(tmp_path: Path) -> None:
     # Single frame image
     out = str(tmp_path / "temp.gif")
     im = hopper()
@@ -274,7 +280,7 @@ def test_roundtrip_save_all(tmp_path):
         assert reread.n_frames == 5
 
 
-def test_roundtrip_save_all_1(tmp_path):
+def test_roundtrip_save_all_1(tmp_path: Path) -> None:
     out = str(tmp_path / "temp.gif")
     im = Image.new("1", (1, 1))
     im2 = Image.new("1", (1, 1), 1)
@@ -295,7 +301,7 @@ def test_roundtrip_save_all_1(tmp_path):
         ("Tests/images/dispose_bgnd_rgba.gif", "RGBA"),
     ),
 )
-def test_loading_multiple_palettes(path, mode):
+def test_loading_multiple_palettes(path: str, mode: str) -> None:
     with Image.open(path) as im:
         assert im.mode == "P"
         first_frame_colors = im.palette.colors.keys()
@@ -313,7 +319,7 @@ def test_loading_multiple_palettes(path, mode):
         assert im.load()[24, 24] not in first_frame_colors
 
 
-def test_headers_saving_for_animated_gifs(tmp_path):
+def test_headers_saving_for_animated_gifs(tmp_path: Path) -> None:
     important_headers = ["background", "version", "duration", "loop"]
     # Multiframe image
     with Image.open("Tests/images/dispose_bgnd.gif") as im:
@@ -326,7 +332,7 @@ def test_headers_saving_for_animated_gifs(tmp_path):
             assert info[header] == reread.info[header]
 
 
-def test_palette_handling(tmp_path):
+def test_palette_handling(tmp_path: Path) -> None:
     # see https://github.com/python-pillow/Pillow/issues/513
 
     with Image.open(TEST_GIF) as im:
@@ -342,12 +348,12 @@ def test_palette_handling(tmp_path):
         assert_image_similar(im, reloaded.convert("RGB"), 10)
 
 
-def test_palette_434(tmp_path):
+def test_palette_434(tmp_path: Path) -> None:
     # see https://github.com/python-pillow/Pillow/issues/434
 
-    def roundtrip(im, *args, **kwargs):
+    def roundtrip(im: Image.Image, **kwargs: bool) -> Image.Image:
         out = str(tmp_path / "temp.gif")
-        im.copy().save(out, *args, **kwargs)
+        im.copy().save(out, **kwargs)
         reloaded = Image.open(out)
 
         return reloaded
@@ -367,28 +373,30 @@ def test_palette_434(tmp_path):
 
 
 @pytest.mark.skipif(not netpbm_available(), reason="Netpbm not available")
-def test_save_netpbm_bmp_mode(tmp_path):
+def test_save_netpbm_bmp_mode(tmp_path: Path) -> None:
     with Image.open(TEST_GIF) as img:
         img = img.convert("RGB")
 
         tempfile = str(tmp_path / "temp.gif")
-        GifImagePlugin._save_netpbm(img, 0, tempfile)
+        b = BytesIO()
+        GifImagePlugin._save_netpbm(img, b, tempfile)
         with Image.open(tempfile) as reloaded:
             assert_image_similar(img, reloaded.convert("RGB"), 0)
 
 
 @pytest.mark.skipif(not netpbm_available(), reason="Netpbm not available")
-def test_save_netpbm_l_mode(tmp_path):
+def test_save_netpbm_l_mode(tmp_path: Path) -> None:
     with Image.open(TEST_GIF) as img:
         img = img.convert("L")
 
         tempfile = str(tmp_path / "temp.gif")
-        GifImagePlugin._save_netpbm(img, 0, tempfile)
+        b = BytesIO()
+        GifImagePlugin._save_netpbm(img, b, tempfile)
         with Image.open(tempfile) as reloaded:
             assert_image_similar(img, reloaded.convert("L"), 0)
 
 
-def test_seek():
+def test_seek() -> None:
     with Image.open("Tests/images/dispose_none.gif") as img:
         frame_count = 0
         try:
@@ -399,7 +407,7 @@ def test_seek():
             assert frame_count == 5
 
 
-def test_seek_info():
+def test_seek_info() -> None:
     with Image.open("Tests/images/iss634.gif") as im:
         info = im.info.copy()
 
@@ -409,7 +417,7 @@ def test_seek_info():
         assert im.info == info
 
 
-def test_seek_rewind():
+def test_seek_rewind() -> None:
     with Image.open("Tests/images/iss634.gif") as im:
         im.seek(2)
         im.seek(1)
@@ -427,7 +435,7 @@ def test_seek_rewind():
         ("Tests/images/iss634.gif", 42),
     ),
 )
-def test_n_frames(path, n_frames):
+def test_n_frames(path: str, n_frames: int) -> None:
     # Test is_animated before n_frames
     with Image.open(path) as im:
         assert im.is_animated == (n_frames != 1)
@@ -438,7 +446,7 @@ def test_n_frames(path, n_frames):
         assert im.is_animated == (n_frames != 1)
 
 
-def test_no_change():
+def test_no_change() -> None:
     # Test n_frames does not change the image
     with Image.open("Tests/images/dispose_bgnd.gif") as im:
         im.seek(1)
@@ -459,7 +467,7 @@ def test_no_change():
         assert_image_equal(im, expected)
 
 
-def test_eoferror():
+def test_eoferror() -> None:
     with Image.open(TEST_GIF) as im:
         n_frames = im.n_frames
 
@@ -472,13 +480,13 @@ def test_eoferror():
         im.seek(n_frames - 1)
 
 
-def test_first_frame_transparency():
+def test_first_frame_transparency() -> None:
     with Image.open("Tests/images/first_frame_transparency.gif") as im:
         px = im.load()
         assert px[0, 0] == im.info["transparency"]
 
 
-def test_dispose_none():
+def test_dispose_none() -> None:
     with Image.open("Tests/images/dispose_none.gif") as img:
         try:
             while True:
@@ -488,7 +496,7 @@ def test_dispose_none():
             pass
 
 
-def test_dispose_none_load_end():
+def test_dispose_none_load_end() -> None:
     # Test image created with:
     #
     # im = Image.open("transparent.gif")
@@ -501,7 +509,7 @@ def test_dispose_none_load_end():
         assert_image_equal_tofile(img, "Tests/images/dispose_none_load_end_second.png")
 
 
-def test_dispose_background():
+def test_dispose_background() -> None:
     with Image.open("Tests/images/dispose_bgnd.gif") as img:
         try:
             while True:
@@ -511,7 +519,7 @@ def test_dispose_background():
             pass
 
 
-def test_dispose_background_transparency():
+def test_dispose_background_transparency() -> None:
     with Image.open("Tests/images/dispose_bgnd_transparency.gif") as img:
         img.seek(2)
         px = img.load()
@@ -539,7 +547,10 @@ def test_dispose_background_transparency():
         ),
     ),
 )
-def test_transparent_dispose(loading_strategy, expected_colors):
+def test_transparent_dispose(
+    loading_strategy: GifImagePlugin.LoadingStrategy,
+    expected_colors: tuple[tuple[int | tuple[int, int, int, int], ...]],
+) -> None:
     GifImagePlugin.LOADING_STRATEGY = loading_strategy
     try:
         with Image.open("Tests/images/transparent_dispose.gif") as img:
@@ -552,7 +563,7 @@ def test_transparent_dispose(loading_strategy, expected_colors):
         GifImagePlugin.LOADING_STRATEGY = GifImagePlugin.LoadingStrategy.RGB_AFTER_FIRST
 
 
-def test_dispose_previous():
+def test_dispose_previous() -> None:
     with Image.open("Tests/images/dispose_prev.gif") as img:
         try:
             while True:
@@ -562,7 +573,7 @@ def test_dispose_previous():
             pass
 
 
-def test_dispose_previous_first_frame():
+def test_dispose_previous_first_frame() -> None:
     with Image.open("Tests/images/dispose_prev_first_frame.gif") as im:
         im.seek(1)
         assert_image_equal_tofile(
@@ -570,7 +581,7 @@ def test_dispose_previous_first_frame():
         )
 
 
-def test_previous_frame_loaded():
+def test_previous_frame_loaded() -> None:
     with Image.open("Tests/images/dispose_none.gif") as img:
         img.load()
         img.seek(1)
@@ -581,7 +592,7 @@ def test_previous_frame_loaded():
             assert_image_equal(img_skipped, img)
 
 
-def test_save_dispose(tmp_path):
+def test_save_dispose(tmp_path: Path) -> None:
     out = str(tmp_path / "temp.gif")
     im_list = [
         Image.new("L", (100, 100), "#000"),
@@ -609,7 +620,7 @@ def test_save_dispose(tmp_path):
             assert img.disposal_method == i + 1
 
 
-def test_dispose2_palette(tmp_path):
+def test_dispose2_palette(tmp_path: Path) -> None:
     out = str(tmp_path / "temp.gif")
 
     # Four colors: white, gray, black, red
@@ -639,8 +650,11 @@ def test_dispose2_palette(tmp_path):
             # Center remains red every frame
             assert rgb_img.getpixel((50, 50)) == circle
 
+            # Check that frame transparency wasn't added unnecessarily
+            assert getattr(img, "_frame_transparency") is None
 
-def test_dispose2_diff(tmp_path):
+
+def test_dispose2_diff(tmp_path: Path) -> None:
     out = str(tmp_path / "temp.gif")
 
     # 4 frames: red/blue, red/red, blue/blue, red/blue
@@ -682,7 +696,7 @@ def test_dispose2_diff(tmp_path):
             assert rgb_img.getpixel((1, 1)) == (255, 255, 255, 0)
 
 
-def test_dispose2_background(tmp_path):
+def test_dispose2_background(tmp_path: Path) -> None:
     out = str(tmp_path / "temp.gif")
 
     im_list = []
@@ -708,7 +722,7 @@ def test_dispose2_background(tmp_path):
         assert im.getpixel((0, 0)) == (255, 0, 0)
 
 
-def test_dispose2_background_frame(tmp_path):
+def test_dispose2_background_frame(tmp_path: Path) -> None:
     out = str(tmp_path / "temp.gif")
 
     im_list = [Image.new("RGBA", (1, 20))]
@@ -726,7 +740,26 @@ def test_dispose2_background_frame(tmp_path):
         assert im.n_frames == 3
 
 
-def test_transparency_in_second_frame(tmp_path):
+def test_dispose2_previous_frame(tmp_path: Path) -> None:
+    out = str(tmp_path / "temp.gif")
+
+    im = Image.new("P", (100, 100))
+    im.info["transparency"] = 0
+    d = ImageDraw.Draw(im)
+    d.rectangle([(0, 0), (100, 50)], 1)
+    im.putpalette((0, 0, 0, 255, 0, 0))
+
+    im2 = Image.new("P", (100, 100))
+    im2.putpalette((0, 0, 0))
+
+    im.save(out, save_all=True, append_images=[im2], disposal=[0, 2])
+
+    with Image.open(out) as im:
+        im.seek(1)
+        assert im.getpixel((0, 0)) == (0, 0, 0, 255)
+
+
+def test_transparency_in_second_frame(tmp_path: Path) -> None:
     out = str(tmp_path / "temp.gif")
     with Image.open("Tests/images/different_transparency.gif") as im:
         assert im.info["transparency"] == 0
@@ -746,7 +779,7 @@ def test_transparency_in_second_frame(tmp_path):
         )
 
 
-def test_no_transparency_in_second_frame():
+def test_no_transparency_in_second_frame() -> None:
     with Image.open("Tests/images/iss634.gif") as img:
         # Seek to the second frame
         img.seek(img.tell() + 1)
@@ -756,7 +789,7 @@ def test_no_transparency_in_second_frame():
         assert img.histogram()[255] == 0
 
 
-def test_remapped_transparency(tmp_path):
+def test_remapped_transparency(tmp_path: Path) -> None:
     out = str(tmp_path / "temp.gif")
 
     im = Image.new("P", (1, 2))
@@ -772,7 +805,7 @@ def test_remapped_transparency(tmp_path):
         assert reloaded.info["transparency"] == reloaded.getpixel((0, 1))
 
 
-def test_duration(tmp_path):
+def test_duration(tmp_path: Path) -> None:
     duration = 1000
 
     out = str(tmp_path / "temp.gif")
@@ -786,7 +819,7 @@ def test_duration(tmp_path):
         assert reread.info["duration"] == duration
 
 
-def test_multiple_duration(tmp_path):
+def test_multiple_duration(tmp_path: Path) -> None:
     duration_list = [1000, 2000, 3000]
 
     out = str(tmp_path / "temp.gif")
@@ -821,7 +854,7 @@ def test_multiple_duration(tmp_path):
                 pass
 
 
-def test_roundtrip_info_duration(tmp_path):
+def test_roundtrip_info_duration(tmp_path: Path) -> None:
     duration_list = [100, 500, 500]
 
     out = str(tmp_path / "temp.gif")
@@ -838,7 +871,7 @@ def test_roundtrip_info_duration(tmp_path):
         ] == duration_list
 
 
-def test_roundtrip_info_duration_combined(tmp_path):
+def test_roundtrip_info_duration_combined(tmp_path: Path) -> None:
     out = str(tmp_path / "temp.gif")
     with Image.open("Tests/images/duplicate_frame.gif") as im:
         assert [frame.info["duration"] for frame in ImageSequence.Iterator(im)] == [
@@ -854,7 +887,7 @@ def test_roundtrip_info_duration_combined(tmp_path):
         ] == [1000, 2000]
 
 
-def test_identical_frames(tmp_path):
+def test_identical_frames(tmp_path: Path) -> None:
     duration_list = [1000, 1500, 2000, 4000]
 
     out = str(tmp_path / "temp.gif")
@@ -887,7 +920,9 @@ def test_identical_frames(tmp_path):
         1500,
     ),
 )
-def test_identical_frames_to_single_frame(duration, tmp_path):
+def test_identical_frames_to_single_frame(
+    duration: int | list[int], tmp_path: Path
+) -> None:
     out = str(tmp_path / "temp.gif")
     im_list = [
         Image.new("L", (100, 100), "#000"),
@@ -904,7 +939,7 @@ def test_identical_frames_to_single_frame(duration, tmp_path):
         assert reread.info["duration"] == 4500
 
 
-def test_loop_none(tmp_path):
+def test_loop_none(tmp_path: Path) -> None:
     out = str(tmp_path / "temp.gif")
     im = Image.new("L", (100, 100), "#000")
     im.save(out, loop=None)
@@ -912,7 +947,7 @@ def test_loop_none(tmp_path):
         assert "loop" not in reread.info
 
 
-def test_number_of_loops(tmp_path):
+def test_number_of_loops(tmp_path: Path) -> None:
     number_of_loops = 2
 
     out = str(tmp_path / "temp.gif")
@@ -930,7 +965,7 @@ def test_number_of_loops(tmp_path):
         assert im.info["loop"] == 2
 
 
-def test_background(tmp_path):
+def test_background(tmp_path: Path) -> None:
     out = str(tmp_path / "temp.gif")
     im = Image.new("L", (100, 100), "#000")
     im.info["background"] = 1
@@ -939,7 +974,7 @@ def test_background(tmp_path):
         assert reread.info["background"] == im.info["background"]
 
 
-def test_webp_background(tmp_path):
+def test_webp_background(tmp_path: Path) -> None:
     out = str(tmp_path / "temp.gif")
 
     # Test opaque WebP background
@@ -954,7 +989,7 @@ def test_webp_background(tmp_path):
     im.save(out)
 
 
-def test_comment(tmp_path):
+def test_comment(tmp_path: Path) -> None:
     with Image.open(TEST_GIF) as im:
         assert im.info["comment"] == b"File written by Adobe Photoshop\xa8 4.0"
 
@@ -974,7 +1009,7 @@ def test_comment(tmp_path):
         assert reread.info["version"] == b"GIF89a"
 
 
-def test_comment_over_255(tmp_path):
+def test_comment_over_255(tmp_path: Path) -> None:
     out = str(tmp_path / "temp.gif")
     im = Image.new("L", (100, 100), "#000")
     comment = b"Test comment text"
@@ -989,18 +1024,18 @@ def test_comment_over_255(tmp_path):
         assert reread.info["version"] == b"GIF89a"
 
 
-def test_zero_comment_subblocks():
+def test_zero_comment_subblocks() -> None:
     with Image.open("Tests/images/hopper_zero_comment_subblocks.gif") as im:
         assert_image_equal_tofile(im, TEST_GIF)
 
 
-def test_read_multiple_comment_blocks():
+def test_read_multiple_comment_blocks() -> None:
     with Image.open("Tests/images/multiple_comments.gif") as im:
         # Multiple comment blocks in a frame are separated not concatenated
         assert im.info["comment"] == b"Test comment 1\nTest comment 2"
 
 
-def test_empty_string_comment(tmp_path):
+def test_empty_string_comment(tmp_path: Path) -> None:
     out = str(tmp_path / "temp.gif")
     with Image.open("Tests/images/chi.gif") as im:
         assert "comment" in im.info
@@ -1013,7 +1048,7 @@ def test_empty_string_comment(tmp_path):
             assert "comment" not in frame.info
 
 
-def test_retain_comment_in_subsequent_frames(tmp_path):
+def test_retain_comment_in_subsequent_frames(tmp_path: Path) -> None:
     # Test that a comment block at the beginning is kept
     with Image.open("Tests/images/chi.gif") as im:
         for frame in ImageSequence.Iterator(im):
@@ -1044,10 +1079,10 @@ def test_retain_comment_in_subsequent_frames(tmp_path):
             assert frame.info["comment"] == b"Test"
 
 
-def test_version(tmp_path):
+def test_version(tmp_path: Path) -> None:
     out = str(tmp_path / "temp.gif")
 
-    def assert_version_after_save(im, version):
+    def assert_version_after_save(im: Image.Image, version: bytes) -> None:
         im.save(out)
         with Image.open(out) as reread:
             assert reread.info["version"] == version
@@ -1074,7 +1109,7 @@ def test_version(tmp_path):
         assert_version_after_save(im, b"GIF87a")
 
 
-def test_append_images(tmp_path):
+def test_append_images(tmp_path: Path) -> None:
     out = str(tmp_path / "temp.gif")
 
     # Test appending single frame images
@@ -1086,7 +1121,7 @@ def test_append_images(tmp_path):
         assert reread.n_frames == 3
 
     # Tests appending using a generator
-    def im_generator(ims):
+    def im_generator(ims: list[Image.Image]) -> Generator[Image.Image, None, None]:
         yield from ims
 
     im.save(out, save_all=True, append_images=im_generator(ims))
@@ -1103,7 +1138,22 @@ def test_append_images(tmp_path):
         assert reread.n_frames == 10
 
 
-def test_transparent_optimize(tmp_path):
+def test_append_different_size_image(tmp_path: Path) -> None:
+    out = str(tmp_path / "temp.gif")
+
+    im = Image.new("RGB", (100, 100))
+    bigger_im = Image.new("RGB", (200, 200), "#f00")
+
+    im.save(out, save_all=True, append_images=[bigger_im])
+
+    with Image.open(out) as reread:
+        assert reread.size == (100, 100)
+
+        reread.seek(1)
+        assert reread.size == (100, 100)
+
+
+def test_transparent_optimize(tmp_path: Path) -> None:
     # From issue #2195, if the transparent color is incorrectly optimized out, GIF loses
     # transparency.
     # Need a palette that isn't using the 0 color,
@@ -1123,7 +1173,7 @@ def test_transparent_optimize(tmp_path):
         assert reloaded.info["transparency"] == reloaded.getpixel((252, 0))
 
 
-def test_removed_transparency(tmp_path):
+def test_removed_transparency(tmp_path: Path) -> None:
     out = str(tmp_path / "temp.gif")
     im = Image.new("RGB", (256, 1))
 
@@ -1138,7 +1188,7 @@ def test_removed_transparency(tmp_path):
         assert "transparency" not in reloaded.info
 
 
-def test_rgb_transparency(tmp_path):
+def test_rgb_transparency(tmp_path: Path) -> None:
     out = str(tmp_path / "temp.gif")
 
     # Single frame
@@ -1160,7 +1210,7 @@ def test_rgb_transparency(tmp_path):
         assert "transparency" not in reloaded.info
 
 
-def test_rgba_transparency(tmp_path):
+def test_rgba_transparency(tmp_path: Path) -> None:
     out = str(tmp_path / "temp.gif")
 
     im = hopper("P")
@@ -1171,13 +1221,13 @@ def test_rgba_transparency(tmp_path):
         assert_image_equal(hopper("P").convert("RGB"), reloaded)
 
 
-def test_background_outside_palettte(tmp_path):
+def test_background_outside_palettte(tmp_path: Path) -> None:
     with Image.open("Tests/images/background_outside_palette.gif") as im:
         im.seek(1)
         assert im.info["background"] == 255
 
 
-def test_bbox(tmp_path):
+def test_bbox(tmp_path: Path) -> None:
     out = str(tmp_path / "temp.gif")
 
     im = Image.new("RGB", (100, 100), "#fff")
@@ -1188,7 +1238,7 @@ def test_bbox(tmp_path):
         assert reread.n_frames == 2
 
 
-def test_bbox_alpha(tmp_path):
+def test_bbox_alpha(tmp_path: Path) -> None:
     out = str(tmp_path / "temp.gif")
 
     im = Image.new("RGBA", (1, 2), (255, 0, 0, 255))
@@ -1200,21 +1250,22 @@ def test_bbox_alpha(tmp_path):
         assert reread.n_frames == 2
 
 
-def test_palette_save_L(tmp_path):
+def test_palette_save_L(tmp_path: Path) -> None:
     # Generate an L mode image with a separate palette
 
     im = hopper("P")
     im_l = Image.frombytes("L", im.size, im.tobytes())
-    palette = bytes(im.getpalette())
+    palette = im.getpalette()
+    assert palette is not None
 
     out = str(tmp_path / "temp.gif")
-    im_l.save(out, palette=palette)
+    im_l.save(out, palette=bytes(palette))
 
     with Image.open(out) as reloaded:
         assert_image_equal(reloaded.convert("RGB"), im.convert("RGB"))
 
 
-def test_palette_save_P(tmp_path):
+def test_palette_save_P(tmp_path: Path) -> None:
     im = Image.new("P", (1, 2))
     im.putpixel((0, 1), 1)
 
@@ -1228,7 +1279,7 @@ def test_palette_save_P(tmp_path):
         assert reloaded_rgb.getpixel((0, 1)) == (4, 5, 6)
 
 
-def test_palette_save_duplicate_entries(tmp_path):
+def test_palette_save_duplicate_entries(tmp_path: Path) -> None:
     im = Image.new("P", (1, 2))
     im.putpixel((0, 1), 1)
 
@@ -1241,7 +1292,7 @@ def test_palette_save_duplicate_entries(tmp_path):
         assert reloaded.convert("RGB").getpixel((0, 1)) == (0, 0, 0)
 
 
-def test_palette_save_all_P(tmp_path):
+def test_palette_save_all_P(tmp_path: Path) -> None:
     frames = []
     colors = ((255, 0, 0), (0, 255, 0))
     for color in colors:
@@ -1264,7 +1315,7 @@ def test_palette_save_all_P(tmp_path):
         assert im.palette.palette == im.global_palette.palette
 
 
-def test_palette_save_ImagePalette(tmp_path):
+def test_palette_save_ImagePalette(tmp_path: Path) -> None:
     # Pass in a different palette, as an ImagePalette.ImagePalette
     # effectively the same as test_palette_save_P
 
@@ -1279,7 +1330,7 @@ def test_palette_save_ImagePalette(tmp_path):
         assert_image_equal(reloaded.convert("RGB"), im.convert("RGB"))
 
 
-def test_save_I(tmp_path):
+def test_save_I(tmp_path: Path) -> None:
     # Test saving something that would trigger the auto-convert to 'L'
 
     im = hopper("I")
@@ -1291,7 +1342,7 @@ def test_save_I(tmp_path):
         assert_image_equal(reloaded.convert("L"), im.convert("L"))
 
 
-def test_getdata():
+def test_getdata() -> None:
     # Test getheader/getdata against legacy values.
     # Create a 'P' image with holes in the palette.
     im = Image._wedge().resize((16, 16), Image.Resampling.NEAREST)
@@ -1319,7 +1370,7 @@ def test_getdata():
         GifImagePlugin._FORCE_OPTIMIZE = False
 
 
-def test_lzw_bits():
+def test_lzw_bits() -> None:
     # see https://github.com/python-pillow/Pillow/issues/2811
     with Image.open("Tests/images/issue_2811.gif") as im:
         assert im.tile[0][3][0] == 11  # LZW bits
@@ -1327,7 +1378,7 @@ def test_lzw_bits():
         im.load()
 
 
-def test_extents():
+def test_extents() -> None:
     with Image.open("Tests/images/test_extents.gif") as im:
         assert im.size == (100, 100)
 
@@ -1339,7 +1390,7 @@ def test_extents():
         assert im.size == (150, 150)
 
 
-def test_missing_background():
+def test_missing_background() -> None:
     # The Global Color Table Flag isn't set, so there is no background color index,
     # but the disposal method is "Restore to background color"
     with Image.open("Tests/images/missing_background.gif") as im:
@@ -1347,7 +1398,7 @@ def test_missing_background():
         assert_image_equal_tofile(im, "Tests/images/missing_background_first_frame.png")
 
 
-def test_saving_rgba(tmp_path):
+def test_saving_rgba(tmp_path: Path) -> None:
     out = str(tmp_path / "temp.gif")
     with Image.open("Tests/images/transparent.png") as im:
         im.save(out)
