@@ -368,16 +368,12 @@ def test_mimetypes(tmp_path: Path) -> None:
 def test_save_stdout(buffer: bool) -> None:
     old_stdout = sys.stdout
 
-    if buffer:
+    class MyStdOut:
+        buffer = BytesIO()
 
-        class MyStdOut:
-            buffer = BytesIO()
+    mystdout: MyStdOut | BytesIO = MyStdOut() if buffer else BytesIO()
 
-        mystdout = MyStdOut()
-    else:
-        mystdout = BytesIO()
-
-    sys.stdout = mystdout
+    sys.stdout = mystdout  # type: ignore[assignment]
 
     with Image.open(TEST_FILE) as im:
         im.save(sys.stdout, "PPM")
@@ -385,7 +381,7 @@ def test_save_stdout(buffer: bool) -> None:
     # Reset stdout
     sys.stdout = old_stdout
 
-    if buffer:
+    if isinstance(mystdout, MyStdOut):
         mystdout = mystdout.buffer
     with Image.open(mystdout) as reloaded:
         assert_image_equal_tofile(reloaded, TEST_FILE)
