@@ -1,4 +1,5 @@
 from __future__ import annotations
+
 import warnings
 
 import pytest
@@ -10,7 +11,7 @@ from .helper import assert_image_equal_tofile, assert_image_similar, hopper, is_
 test_file = "Tests/images/hopper.psd"
 
 
-def test_sanity():
+def test_sanity() -> None:
     with Image.open(test_file) as im:
         im.load()
         assert im.mode == "RGB"
@@ -23,8 +24,8 @@ def test_sanity():
 
 
 @pytest.mark.skipif(is_pypy(), reason="Requires CPython")
-def test_unclosed_file():
-    def open():
+def test_unclosed_file() -> None:
+    def open() -> None:
         im = Image.open(test_file)
         im.load()
 
@@ -32,27 +33,27 @@ def test_unclosed_file():
         open()
 
 
-def test_closed_file():
+def test_closed_file() -> None:
     with warnings.catch_warnings():
         im = Image.open(test_file)
         im.load()
         im.close()
 
 
-def test_context_manager():
+def test_context_manager() -> None:
     with warnings.catch_warnings():
         with Image.open(test_file) as im:
             im.load()
 
 
-def test_invalid_file():
+def test_invalid_file() -> None:
     invalid_file = "Tests/images/flower.jpg"
 
     with pytest.raises(SyntaxError):
         PsdImagePlugin.PsdImageFile(invalid_file)
 
 
-def test_n_frames():
+def test_n_frames() -> None:
     with Image.open("Tests/images/hopper_merged.psd") as im:
         assert im.n_frames == 1
         assert not im.is_animated
@@ -63,7 +64,7 @@ def test_n_frames():
             assert im.is_animated
 
 
-def test_eoferror():
+def test_eoferror() -> None:
     with Image.open(test_file) as im:
         # PSD seek index starts at 1 rather than 0
         n_frames = im.n_frames + 1
@@ -77,7 +78,7 @@ def test_eoferror():
         im.seek(n_frames - 1)
 
 
-def test_seek_tell():
+def test_seek_tell() -> None:
     with Image.open(test_file) as im:
         layer_number = im.tell()
         assert layer_number == 1
@@ -94,30 +95,35 @@ def test_seek_tell():
         assert layer_number == 2
 
 
-def test_seek_eoferror():
+def test_seek_eoferror() -> None:
     with Image.open(test_file) as im:
         with pytest.raises(EOFError):
             im.seek(-1)
 
 
-def test_open_after_exclusive_load():
+def test_open_after_exclusive_load() -> None:
     with Image.open(test_file) as im:
         im.load()
         im.seek(im.tell() + 1)
         im.load()
 
 
-def test_rgba():
+def test_rgba() -> None:
     with Image.open("Tests/images/rgba.psd") as im:
         assert_image_equal_tofile(im, "Tests/images/imagedraw_square.png")
 
 
-def test_layer_skip():
+def test_negative_top_left_layer() -> None:
+    with Image.open("Tests/images/negative_top_left_layer.psd") as im:
+        assert im.layers[0][2] == (-50, -50, 50, 50)
+
+
+def test_layer_skip() -> None:
     with Image.open("Tests/images/five_channels.psd") as im:
         assert im.n_frames == 1
 
 
-def test_icc_profile():
+def test_icc_profile() -> None:
     with Image.open(test_file) as im:
         assert "icc_profile" in im.info
 
@@ -125,12 +131,12 @@ def test_icc_profile():
         assert len(icc_profile) == 3144
 
 
-def test_no_icc_profile():
+def test_no_icc_profile() -> None:
     with Image.open("Tests/images/hopper_merged.psd") as im:
         assert "icc_profile" not in im.info
 
 
-def test_combined_larger_than_size():
+def test_combined_larger_than_size() -> None:
     # The combined size of the individual parts is larger than the
     # declared 'size' of the extra data field, resulting in a backwards seek.
 
@@ -144,20 +150,26 @@ def test_combined_larger_than_size():
 @pytest.mark.parametrize(
     "test_file,raises",
     [
-        (
-            "Tests/images/timeout-1ee28a249896e05b83840ae8140622de8e648ba9.psd",
-            Image.UnidentifiedImageError,
-        ),
-        (
-            "Tests/images/timeout-598843abc37fc080ec36a2699ebbd44f795d3a6f.psd",
-            Image.UnidentifiedImageError,
-        ),
         ("Tests/images/timeout-c8efc3fded6426986ba867a399791bae544f59bc.psd", OSError),
         ("Tests/images/timeout-dedc7a4ebd856d79b4359bbcc79e8ef231ce38f6.psd", OSError),
     ],
 )
-def test_crashes(test_file, raises):
+def test_crashes(test_file: str, raises: type[Exception]) -> None:
     with open(test_file, "rb") as f:
         with pytest.raises(raises):
             with Image.open(f):
                 pass
+
+
+@pytest.mark.parametrize(
+    "test_file",
+    [
+        "Tests/images/timeout-1ee28a249896e05b83840ae8140622de8e648ba9.psd",
+        "Tests/images/timeout-598843abc37fc080ec36a2699ebbd44f795d3a6f.psd",
+    ],
+)
+def test_layer_crashes(test_file: str) -> None:
+    with open(test_file, "rb") as f:
+        with Image.open(f) as im:
+            with pytest.raises(SyntaxError):
+                im.layers
