@@ -1,7 +1,11 @@
 from __future__ import annotations
+
 import os
 import warnings
 from io import BytesIO
+from pathlib import Path
+from types import ModuleType
+from typing import Generator
 
 import pytest
 
@@ -18,6 +22,7 @@ from .helper import (
     is_win32,
 )
 
+ElementTree: ModuleType | None
 try:
     from defusedxml import ElementTree
 except ImportError:
@@ -25,7 +30,7 @@ except ImportError:
 
 
 class TestFileTiff:
-    def test_sanity(self, tmp_path):
+    def test_sanity(self, tmp_path: Path) -> None:
         filename = str(tmp_path / "temp.tif")
 
         hopper("RGB").save(filename)
@@ -57,21 +62,21 @@ class TestFileTiff:
             pass
 
     @pytest.mark.skipif(is_pypy(), reason="Requires CPython")
-    def test_unclosed_file(self):
-        def open():
+    def test_unclosed_file(self) -> None:
+        def open() -> None:
             im = Image.open("Tests/images/multipage.tiff")
             im.load()
 
         with pytest.warns(ResourceWarning):
             open()
 
-    def test_closed_file(self):
+    def test_closed_file(self) -> None:
         with warnings.catch_warnings():
             im = Image.open("Tests/images/multipage.tiff")
             im.load()
             im.close()
 
-    def test_seek_after_close(self):
+    def test_seek_after_close(self) -> None:
         im = Image.open("Tests/images/multipage.tiff")
         im.close()
 
@@ -80,12 +85,12 @@ class TestFileTiff:
         with pytest.raises(ValueError):
             im.seek(1)
 
-    def test_context_manager(self):
+    def test_context_manager(self) -> None:
         with warnings.catch_warnings():
             with Image.open("Tests/images/multipage.tiff") as im:
                 im.load()
 
-    def test_mac_tiff(self):
+    def test_mac_tiff(self) -> None:
         # Read RGBa images from macOS [@PIL136]
 
         filename = "Tests/images/pil136.tiff"
@@ -97,7 +102,7 @@ class TestFileTiff:
 
             assert_image_similar_tofile(im, "Tests/images/pil136.png", 1)
 
-    def test_bigtiff(self, tmp_path):
+    def test_bigtiff(self, tmp_path: Path) -> None:
         with Image.open("Tests/images/hopper_bigtiff.tif") as im:
             assert_image_equal_tofile(im, "Tests/images/hopper.tif")
 
@@ -108,13 +113,17 @@ class TestFileTiff:
             outfile = str(tmp_path / "temp.tif")
             im.save(outfile, save_all=True, append_images=[im], tiffinfo=im.tag_v2)
 
-    def test_set_legacy_api(self):
+    def test_seek_too_large(self) -> None:
+        with pytest.raises(ValueError, match="Unable to seek to frame"):
+            Image.open("Tests/images/seek_too_large.tif")
+
+    def test_set_legacy_api(self) -> None:
         ifd = TiffImagePlugin.ImageFileDirectory_v2()
         with pytest.raises(Exception) as e:
-            ifd.legacy_api = None
+            ifd.legacy_api = False
         assert str(e.value) == "Not allowing setting of legacy api"
 
-    def test_xyres_tiff(self):
+    def test_xyres_tiff(self) -> None:
         filename = "Tests/images/pil168.tif"
         with Image.open(filename) as im:
             # legacy api
@@ -127,7 +136,7 @@ class TestFileTiff:
 
             assert im.info["dpi"] == (72.0, 72.0)
 
-    def test_xyres_fallback_tiff(self):
+    def test_xyres_fallback_tiff(self) -> None:
         filename = "Tests/images/compression.tif"
         with Image.open(filename) as im:
             # v2 api
@@ -141,7 +150,7 @@ class TestFileTiff:
             # Fallback "inch".
             assert im.info["dpi"] == (100.0, 100.0)
 
-    def test_int_resolution(self):
+    def test_int_resolution(self) -> None:
         filename = "Tests/images/pil168.tif"
         with Image.open(filename) as im:
             # Try to read a file where X,Y_RESOLUTION are ints
@@ -154,14 +163,14 @@ class TestFileTiff:
         "resolution_unit, dpi",
         [(None, 72.8), (2, 72.8), (3, 184.912)],
     )
-    def test_load_float_dpi(self, resolution_unit, dpi):
+    def test_load_float_dpi(self, resolution_unit: int | None, dpi: float) -> None:
         with Image.open(
             "Tests/images/hopper_float_dpi_" + str(resolution_unit) + ".tif"
         ) as im:
             assert im.tag_v2.get(RESOLUTION_UNIT) == resolution_unit
             assert im.info["dpi"] == (dpi, dpi)
 
-    def test_save_float_dpi(self, tmp_path):
+    def test_save_float_dpi(self, tmp_path: Path) -> None:
         outfile = str(tmp_path / "temp.tif")
         with Image.open("Tests/images/hopper.tif") as im:
             dpi = (72.2, 72.2)
@@ -170,7 +179,7 @@ class TestFileTiff:
             with Image.open(outfile) as reloaded:
                 assert reloaded.info["dpi"] == dpi
 
-    def test_save_setting_missing_resolution(self):
+    def test_save_setting_missing_resolution(self) -> None:
         b = BytesIO()
         with Image.open("Tests/images/10ct_32bit_128.tiff") as im:
             im.save(b, format="tiff", resolution=123.45)
@@ -178,7 +187,7 @@ class TestFileTiff:
             assert im.tag_v2[X_RESOLUTION] == 123.45
             assert im.tag_v2[Y_RESOLUTION] == 123.45
 
-    def test_invalid_file(self):
+    def test_invalid_file(self) -> None:
         invalid_file = "Tests/images/flower.jpg"
 
         with pytest.raises(SyntaxError):
@@ -189,30 +198,30 @@ class TestFileTiff:
             TiffImagePlugin.TiffImageFile(invalid_file)
         TiffImagePlugin.PREFIXES.pop()
 
-    def test_bad_exif(self):
+    def test_bad_exif(self) -> None:
         with Image.open("Tests/images/hopper_bad_exif.jpg") as i:
             # Should not raise struct.error.
             with pytest.warns(UserWarning):
                 i._getexif()
 
-    def test_save_rgba(self, tmp_path):
+    def test_save_rgba(self, tmp_path: Path) -> None:
         im = hopper("RGBA")
         outfile = str(tmp_path / "temp.tif")
         im.save(outfile)
 
-    def test_save_unsupported_mode(self, tmp_path):
+    def test_save_unsupported_mode(self, tmp_path: Path) -> None:
         im = hopper("HSV")
         outfile = str(tmp_path / "temp.tif")
         with pytest.raises(OSError):
             im.save(outfile)
 
-    def test_8bit_s(self):
+    def test_8bit_s(self) -> None:
         with Image.open("Tests/images/8bit.s.tif") as im:
             im.load()
             assert im.mode == "L"
             assert im.getpixel((50, 50)) == 184
 
-    def test_little_endian(self):
+    def test_little_endian(self) -> None:
         with Image.open("Tests/images/16bit.cropped.tif") as im:
             assert im.getpixel((0, 0)) == 480
             assert im.mode == "I;16"
@@ -222,7 +231,7 @@ class TestFileTiff:
         assert b[0] == ord(b"\xe0")
         assert b[1] == ord(b"\x01")
 
-    def test_big_endian(self):
+    def test_big_endian(self) -> None:
         with Image.open("Tests/images/16bit.MM.cropped.tif") as im:
             assert im.getpixel((0, 0)) == 480
             assert im.mode == "I;16B"
@@ -232,7 +241,7 @@ class TestFileTiff:
         assert b[0] == ord(b"\x01")
         assert b[1] == ord(b"\xe0")
 
-    def test_16bit_r(self):
+    def test_16bit_r(self) -> None:
         with Image.open("Tests/images/16bit.r.tif") as im:
             assert im.getpixel((0, 0)) == 480
             assert im.mode == "I;16"
@@ -241,14 +250,14 @@ class TestFileTiff:
         assert b[0] == ord(b"\xe0")
         assert b[1] == ord(b"\x01")
 
-    def test_16bit_s(self):
+    def test_16bit_s(self) -> None:
         with Image.open("Tests/images/16bit.s.tif") as im:
             im.load()
             assert im.mode == "I"
             assert im.getpixel((0, 0)) == 32767
             assert im.getpixel((0, 1)) == 0
 
-    def test_12bit_rawmode(self):
+    def test_12bit_rawmode(self) -> None:
         """Are we generating the same interpretation
         of the image as Imagemagick is?"""
 
@@ -261,7 +270,7 @@ class TestFileTiff:
 
             assert_image_equal_tofile(im, "Tests/images/12in16bit.tif")
 
-    def test_32bit_float(self):
+    def test_32bit_float(self) -> None:
         # Issue 614, specific 32-bit float format
         path = "Tests/images/10ct_32bit_128.tiff"
         with Image.open(path) as im:
@@ -270,7 +279,7 @@ class TestFileTiff:
             assert im.getpixel((0, 0)) == -0.4526388943195343
             assert im.getextrema() == (-3.140936851501465, 3.140684127807617)
 
-    def test_unknown_pixel_mode(self):
+    def test_unknown_pixel_mode(self) -> None:
         with pytest.raises(OSError):
             with Image.open("Tests/images/hopper_unknown_pixel_mode.tif"):
                 pass
@@ -282,12 +291,12 @@ class TestFileTiff:
             ("Tests/images/multipage.tiff", 3),
         ),
     )
-    def test_n_frames(self, path, n_frames):
+    def test_n_frames(self, path: str, n_frames: int) -> None:
         with Image.open(path) as im:
             assert im.n_frames == n_frames
             assert im.is_animated == (n_frames != 1)
 
-    def test_eoferror(self):
+    def test_eoferror(self) -> None:
         with Image.open("Tests/images/multipage-lastframe.tif") as im:
             n_frames = im.n_frames
 
@@ -299,7 +308,7 @@ class TestFileTiff:
             # Test that seeking to the last frame does not raise an error
             im.seek(n_frames - 1)
 
-    def test_multipage(self):
+    def test_multipage(self) -> None:
         # issue #862
         with Image.open("Tests/images/multipage.tiff") as im:
             # file is a multipage tiff: 10x10 green, 10x10 red, 20x20 blue
@@ -323,13 +332,13 @@ class TestFileTiff:
             assert im.size == (20, 20)
             assert im.convert("RGB").getpixel((0, 0)) == (0, 0, 255)
 
-    def test_multipage_last_frame(self):
+    def test_multipage_last_frame(self) -> None:
         with Image.open("Tests/images/multipage-lastframe.tif") as im:
             im.load()
             assert im.size == (20, 20)
             assert im.convert("RGB").getpixel((0, 0)) == (0, 0, 255)
 
-    def test_frame_order(self):
+    def test_frame_order(self) -> None:
         # A frame can't progress to itself after reading
         with Image.open("Tests/images/multipage_single_frame_loop.tiff") as im:
             assert im.n_frames == 1
@@ -342,7 +351,7 @@ class TestFileTiff:
         with Image.open("Tests/images/multipage_out_of_order.tiff") as im:
             assert im.n_frames == 3
 
-    def test___str__(self):
+    def test___str__(self) -> None:
         filename = "Tests/images/pil136.tiff"
         with Image.open(filename) as im:
             # Act
@@ -351,7 +360,7 @@ class TestFileTiff:
             # Assert
             assert isinstance(ret, str)
 
-    def test_dict(self):
+    def test_dict(self) -> None:
         # Arrange
         filename = "Tests/images/pil136.tiff"
         with Image.open(filename) as im:
@@ -391,7 +400,7 @@ class TestFileTiff:
             }
             assert dict(im.tag) == legacy_tags
 
-    def test__delitem__(self):
+    def test__delitem__(self) -> None:
         filename = "Tests/images/pil136.tiff"
         with Image.open(filename) as im:
             len_before = len(dict(im.ifd))
@@ -400,36 +409,36 @@ class TestFileTiff:
             assert len_before == len_after + 1
 
     @pytest.mark.parametrize("legacy_api", (False, True))
-    def test_load_byte(self, legacy_api):
+    def test_load_byte(self, legacy_api: bool) -> None:
         ifd = TiffImagePlugin.ImageFileDirectory_v2()
         data = b"abc"
         ret = ifd.load_byte(data, legacy_api)
         assert ret == b"abc"
 
-    def test_load_string(self):
+    def test_load_string(self) -> None:
         ifd = TiffImagePlugin.ImageFileDirectory_v2()
         data = b"abc\0"
         ret = ifd.load_string(data, False)
         assert ret == "abc"
 
-    def test_load_float(self):
+    def test_load_float(self) -> None:
         ifd = TiffImagePlugin.ImageFileDirectory_v2()
         data = b"abcdabcd"
         ret = ifd.load_float(data, False)
         assert ret == (1.6777999408082104e22, 1.6777999408082104e22)
 
-    def test_load_double(self):
+    def test_load_double(self) -> None:
         ifd = TiffImagePlugin.ImageFileDirectory_v2()
         data = b"abcdefghabcdefgh"
         ret = ifd.load_double(data, False)
         assert ret == (8.540883223036124e194, 8.540883223036124e194)
 
-    def test_ifd_tag_type(self):
+    def test_ifd_tag_type(self) -> None:
         with Image.open("Tests/images/ifd_tag_type.tiff") as im:
             assert 0x8825 in im.tag_v2
 
-    def test_exif(self, tmp_path):
-        def check_exif(exif):
+    def test_exif(self, tmp_path: Path) -> None:
+        def check_exif(exif: Image.Exif) -> None:
             assert sorted(exif.keys()) == [
                 256,
                 257,
@@ -480,7 +489,7 @@ class TestFileTiff:
             exif = im.getexif()
             check_exif(exif)
 
-    def test_modify_exif(self, tmp_path):
+    def test_modify_exif(self, tmp_path: Path) -> None:
         outfile = str(tmp_path / "temp.tif")
         with Image.open("Tests/images/ifd_tag_type.tiff") as im:
             exif = im.getexif()
@@ -492,7 +501,7 @@ class TestFileTiff:
             exif = im.getexif()
             assert exif[264] == 100
 
-    def test_reload_exif_after_seek(self):
+    def test_reload_exif_after_seek(self) -> None:
         with Image.open("Tests/images/multipage.tiff") as im:
             exif = im.getexif()
             del exif[256]
@@ -500,7 +509,7 @@ class TestFileTiff:
 
             assert 256 in exif
 
-    def test_exif_frames(self):
+    def test_exif_frames(self) -> None:
         # Test that EXIF data can change across frames
         with Image.open("Tests/images/g4-multi.tiff") as im:
             assert im.getexif()[273] == (328, 815)
@@ -509,7 +518,7 @@ class TestFileTiff:
             assert im.getexif()[273] == (1408, 1907)
 
     @pytest.mark.parametrize("mode", ("1", "L"))
-    def test_photometric(self, mode, tmp_path):
+    def test_photometric(self, mode: str, tmp_path: Path) -> None:
         filename = str(tmp_path / "temp.tif")
         im = hopper(mode)
         im.save(filename, tiffinfo={262: 0})
@@ -517,13 +526,13 @@ class TestFileTiff:
             assert reloaded.tag_v2[262] == 0
             assert_image_equal(im, reloaded)
 
-    def test_seek(self):
+    def test_seek(self) -> None:
         filename = "Tests/images/pil136.tiff"
         with Image.open(filename) as im:
             im.seek(0)
             assert im.tell() == 0
 
-    def test_seek_eof(self):
+    def test_seek_eof(self) -> None:
         filename = "Tests/images/pil136.tiff"
         with Image.open(filename) as im:
             assert im.tell() == 0
@@ -532,21 +541,21 @@ class TestFileTiff:
             with pytest.raises(EOFError):
                 im.seek(1)
 
-    def test__limit_rational_int(self):
+    def test__limit_rational_int(self) -> None:
         from PIL.TiffImagePlugin import _limit_rational
 
         value = 34
         ret = _limit_rational(value, 65536)
         assert ret == (34, 1)
 
-    def test__limit_rational_float(self):
+    def test__limit_rational_float(self) -> None:
         from PIL.TiffImagePlugin import _limit_rational
 
         value = 22.3
         ret = _limit_rational(value, 65536)
         assert ret == (223, 10)
 
-    def test_4bit(self):
+    def test_4bit(self) -> None:
         test_file = "Tests/images/hopper_gray_4bpp.tif"
         original = hopper("L")
         with Image.open(test_file) as im:
@@ -554,7 +563,7 @@ class TestFileTiff:
             assert im.mode == "L"
             assert_image_similar(im, original, 7.3)
 
-    def test_gray_semibyte_per_pixel(self):
+    def test_gray_semibyte_per_pixel(self) -> None:
         test_files = (
             (
                 24.8,  # epsilon
@@ -587,7 +596,7 @@ class TestFileTiff:
                         assert im2.mode == "L"
                         assert_image_equal(im, im2)
 
-    def test_with_underscores(self, tmp_path):
+    def test_with_underscores(self, tmp_path: Path) -> None:
         kwargs = {"resolution_unit": "inch", "x_resolution": 72, "y_resolution": 36}
         filename = str(tmp_path / "temp.tif")
         hopper("RGB").save(filename, **kwargs)
@@ -600,7 +609,7 @@ class TestFileTiff:
             assert im.tag_v2[X_RESOLUTION] == 72
             assert im.tag_v2[Y_RESOLUTION] == 36
 
-    def test_roundtrip_tiff_uint16(self, tmp_path):
+    def test_roundtrip_tiff_uint16(self, tmp_path: Path) -> None:
         # Test an image of all '0' values
         pixel_value = 0x1234
         infile = "Tests/images/uint16_1_4660.tif"
@@ -612,33 +621,47 @@ class TestFileTiff:
 
             assert_image_equal_tofile(im, tmpfile)
 
-    def test_rowsperstrip(self, tmp_path):
+    def test_iptc(self, tmp_path: Path) -> None:
+        # Do not preserve IPTC_NAA_CHUNK by default if type is LONG
+        outfile = str(tmp_path / "temp.tif")
+        im = hopper()
+        ifd = TiffImagePlugin.ImageFileDirectory_v2()
+        ifd[33723] = 1
+        ifd.tagtype[33723] = 4
+        im.tag_v2 = ifd
+        im.save(outfile)
+
+        with Image.open(outfile) as im:
+            assert 33723 not in im.tag_v2
+
+    def test_rowsperstrip(self, tmp_path: Path) -> None:
         outfile = str(tmp_path / "temp.tif")
         im = hopper()
         im.save(outfile, tiffinfo={278: 256})
 
         with Image.open(outfile) as im:
+            assert isinstance(im, TiffImagePlugin.TiffImageFile)
             assert im.tag_v2[278] == 256
 
-    def test_strip_raw(self):
+    def test_strip_raw(self) -> None:
         infile = "Tests/images/tiff_strip_raw.tif"
         with Image.open(infile) as im:
             assert_image_equal_tofile(im, "Tests/images/tiff_adobe_deflate.png")
 
-    def test_strip_planar_raw(self):
+    def test_strip_planar_raw(self) -> None:
         # gdal_translate -of GTiff -co INTERLEAVE=BAND \
         # tiff_strip_raw.tif tiff_strip_planar_raw.tiff
         infile = "Tests/images/tiff_strip_planar_raw.tif"
         with Image.open(infile) as im:
             assert_image_equal_tofile(im, "Tests/images/tiff_adobe_deflate.png")
 
-    def test_strip_planar_raw_with_overviews(self):
+    def test_strip_planar_raw_with_overviews(self) -> None:
         # gdaladdo tiff_strip_planar_raw2.tif 2 4 8 16
         infile = "Tests/images/tiff_strip_planar_raw_with_overviews.tif"
         with Image.open(infile) as im:
             assert_image_equal_tofile(im, "Tests/images/tiff_adobe_deflate.png")
 
-    def test_tiled_planar_raw(self):
+    def test_tiled_planar_raw(self) -> None:
         # gdal_translate -of GTiff -co TILED=YES -co BLOCKXSIZE=32 \
         # -co BLOCKYSIZE=32 -co INTERLEAVE=BAND \
         # tiff_tiled_raw.tif tiff_tiled_planar_raw.tiff
@@ -646,7 +669,7 @@ class TestFileTiff:
         with Image.open(infile) as im:
             assert_image_equal_tofile(im, "Tests/images/tiff_adobe_deflate.png")
 
-    def test_planar_configuration_save(self, tmp_path):
+    def test_planar_configuration_save(self, tmp_path: Path) -> None:
         infile = "Tests/images/tiff_tiled_planar_raw.tif"
         with Image.open(infile) as im:
             assert im._planar_configuration == 2
@@ -658,7 +681,7 @@ class TestFileTiff:
                 assert_image_equal_tofile(reloaded, infile)
 
     @pytest.mark.parametrize("mode", ("P", "PA"))
-    def test_palette(self, mode, tmp_path):
+    def test_palette(self, mode: str, tmp_path: Path) -> None:
         outfile = str(tmp_path / "temp.tif")
 
         im = hopper(mode)
@@ -667,7 +690,7 @@ class TestFileTiff:
         with Image.open(outfile) as reloaded:
             assert_image_equal(im.convert("RGB"), reloaded.convert("RGB"))
 
-    def test_tiff_save_all(self):
+    def test_tiff_save_all(self) -> None:
         mp = BytesIO()
         with Image.open("Tests/images/multipage.tiff") as im:
             im.save(mp, format="tiff", save_all=True)
@@ -687,7 +710,7 @@ class TestFileTiff:
             assert reread.n_frames == 3
 
         # Test appending using a generator
-        def im_generator(ims):
+        def im_generator(ims: list[Image.Image]) -> Generator[Image.Image, None, None]:
             yield from ims
 
         mp = BytesIO()
@@ -697,7 +720,7 @@ class TestFileTiff:
         with Image.open(mp) as reread:
             assert reread.n_frames == 3
 
-    def test_saving_icc_profile(self, tmp_path):
+    def test_saving_icc_profile(self, tmp_path: Path) -> None:
         # Tests saving TIFF with icc_profile set.
         # At the time of writing this will only work for non-compressed tiffs
         # as libtiff does not support embedded ICC profiles,
@@ -711,7 +734,7 @@ class TestFileTiff:
         with Image.open(tmpfile) as reloaded:
             assert b"Dummy value" == reloaded.info["icc_profile"]
 
-    def test_save_icc_profile(self, tmp_path):
+    def test_save_icc_profile(self, tmp_path: Path) -> None:
         im = hopper()
         assert "icc_profile" not in im.info
 
@@ -722,14 +745,14 @@ class TestFileTiff:
         with Image.open(outfile) as reloaded:
             assert reloaded.info["icc_profile"] == icc_profile
 
-    def test_save_bmp_compression(self, tmp_path):
+    def test_save_bmp_compression(self, tmp_path: Path) -> None:
         with Image.open("Tests/images/hopper.bmp") as im:
             assert im.info["compression"] == 0
 
             outfile = str(tmp_path / "temp.tif")
             im.save(outfile)
 
-    def test_discard_icc_profile(self, tmp_path):
+    def test_discard_icc_profile(self, tmp_path: Path) -> None:
         outfile = str(tmp_path / "temp.tif")
 
         with Image.open("Tests/images/icc_profile.png") as im:
@@ -740,7 +763,7 @@ class TestFileTiff:
         with Image.open(outfile) as reloaded:
             assert "icc_profile" not in reloaded.info
 
-    def test_getxmp(self):
+    def test_getxmp(self) -> None:
         with Image.open("Tests/images/lab.tif") as im:
             if ElementTree is None:
                 with pytest.warns(
@@ -749,13 +772,14 @@ class TestFileTiff:
                 ):
                     assert im.getxmp() == {}
             else:
+                assert "xmp" in im.info
                 xmp = im.getxmp()
 
                 description = xmp["xmpmeta"]["RDF"]["Description"]
                 assert description[0]["format"] == "image/tiff"
                 assert description[3]["BitsPerSample"]["Seq"]["li"] == ["8", "8", "8"]
 
-    def test_get_photoshop_blocks(self):
+    def test_get_photoshop_blocks(self) -> None:
         with Image.open("Tests/images/lab.tif") as im:
             assert list(im.get_photoshop_blocks().keys()) == [
                 1061,
@@ -781,7 +805,7 @@ class TestFileTiff:
                 4001,
             ]
 
-    def test_tiff_chunks(self, tmp_path):
+    def test_tiff_chunks(self, tmp_path: Path) -> None:
         tmpfile = str(tmp_path / "temp.tif")
 
         im = hopper()
@@ -802,7 +826,7 @@ class TestFileTiff:
 
         assert_image_equal_tofile(im, tmpfile)
 
-    def test_close_on_load_exclusive(self, tmp_path):
+    def test_close_on_load_exclusive(self, tmp_path: Path) -> None:
         # similar to test_fd_leak, but runs on unixlike os
         tmpfile = str(tmp_path / "temp.tif")
 
@@ -815,7 +839,7 @@ class TestFileTiff:
         im.load()
         assert fp.closed
 
-    def test_close_on_load_nonexclusive(self, tmp_path):
+    def test_close_on_load_nonexclusive(self, tmp_path: Path) -> None:
         tmpfile = str(tmp_path / "temp.tif")
 
         with Image.open("Tests/images/uint16_1_4660.tif") as im:
@@ -837,7 +861,7 @@ class TestFileTiff:
         not os.path.exists("Tests/images/string_dimension.tiff"),
         reason="Extra image files not installed",
     )
-    def test_string_dimension(self):
+    def test_string_dimension(self) -> None:
         # Assert that an error is raised if one of the dimensions is a string
         with Image.open("Tests/images/string_dimension.tiff") as im:
             with pytest.raises(OSError):
@@ -845,7 +869,7 @@ class TestFileTiff:
 
     @pytest.mark.timeout(6)
     @pytest.mark.filterwarnings("ignore:Truncated File Read")
-    def test_timeout(self):
+    def test_timeout(self) -> None:
         with Image.open("Tests/images/timeout-6646305047838720") as im:
             ImageFile.LOAD_TRUNCATED_IMAGES = True
             im.load()
@@ -858,7 +882,7 @@ class TestFileTiff:
         ],
     )
     @pytest.mark.timeout(2)
-    def test_oom(self, test_file):
+    def test_oom(self, test_file: str) -> None:
         with pytest.raises(UnidentifiedImageError):
             with pytest.warns(UserWarning):
                 with Image.open(test_file):
@@ -867,7 +891,7 @@ class TestFileTiff:
 
 @pytest.mark.skipif(not is_win32(), reason="Windows only")
 class TestFileTiffW32:
-    def test_fd_leak(self, tmp_path):
+    def test_fd_leak(self, tmp_path: Path) -> None:
         tmpfile = str(tmp_path / "temp.tif")
 
         # this is an mmaped file.
