@@ -1,4 +1,7 @@
 from __future__ import annotations
+
+from pathlib import Path
+
 import pytest
 from packaging.version import parse as parse_version
 
@@ -17,7 +20,7 @@ pytestmark = [
 ]
 
 
-def test_n_frames():
+def test_n_frames() -> None:
     """Ensure that WebP format sets n_frames and is_animated attributes correctly."""
 
     with Image.open("Tests/images/hopper.webp") as im:
@@ -29,7 +32,7 @@ def test_n_frames():
         assert im.is_animated
 
 
-def test_write_animation_L(tmp_path):
+def test_write_animation_L(tmp_path: Path) -> None:
     """
     Convert an animated GIF to animated WebP, then compare the frame count, and first
     and last frames to ensure they're visually similar.
@@ -49,8 +52,9 @@ def test_write_animation_L(tmp_path):
             assert_image_similar(im, orig.convert("RGBA"), 32.9)
 
             if is_big_endian():
-                webp = parse_version(features.version_module("webp"))
-                if webp < parse_version("1.2.2"):
+                version = features.version_module("webp")
+                assert version is not None
+                if parse_version(version) < parse_version("1.2.2"):
                     pytest.skip("Fails with libwebp earlier than 1.2.2")
             orig.seek(orig.n_frames - 1)
             im.seek(im.n_frames - 1)
@@ -59,13 +63,13 @@ def test_write_animation_L(tmp_path):
             assert_image_similar(im, orig.convert("RGBA"), 32.9)
 
 
-def test_write_animation_RGB(tmp_path):
+def test_write_animation_RGB(tmp_path: Path) -> None:
     """
     Write an animated WebP from RGB frames, and ensure the frames
     are visually similar to the originals.
     """
 
-    def check(temp_file):
+    def check(temp_file: str) -> None:
         with Image.open(temp_file) as im:
             assert im.n_frames == 2
 
@@ -75,8 +79,9 @@ def test_write_animation_RGB(tmp_path):
 
             # Compare second frame to original
             if is_big_endian():
-                webp = parse_version(features.version_module("webp"))
-                if webp < parse_version("1.2.2"):
+                version = features.version_module("webp")
+                assert version is not None
+                if parse_version(version) < parse_version("1.2.2"):
                     pytest.skip("Fails with libwebp earlier than 1.2.2")
             im.seek(1)
             im.load()
@@ -104,7 +109,7 @@ def test_write_animation_RGB(tmp_path):
             check(temp_file2)
 
 
-def test_timestamp_and_duration(tmp_path):
+def test_timestamp_and_duration(tmp_path: Path) -> None:
     """
     Try passing a list of durations, and make sure the encoded
     timestamps and durations are correct.
@@ -135,7 +140,7 @@ def test_timestamp_and_duration(tmp_path):
             ts += durations[frame]
 
 
-def test_float_duration(tmp_path):
+def test_float_duration(tmp_path: Path) -> None:
     temp_file = str(tmp_path / "temp.webp")
     with Image.open("Tests/images/iss634.apng") as im:
         assert im.info["duration"] == 70.0
@@ -147,7 +152,7 @@ def test_float_duration(tmp_path):
         assert reloaded.info["duration"] == 70
 
 
-def test_seeking(tmp_path):
+def test_seeking(tmp_path: Path) -> None:
     """
     Create an animated WebP file, and then try seeking through frames in reverse-order,
     verifying the timestamps and durations are correct.
@@ -178,10 +183,28 @@ def test_seeking(tmp_path):
             ts -= dur
 
 
-def test_seek_errors():
+def test_seek_errors() -> None:
     with Image.open("Tests/images/iss634.webp") as im:
         with pytest.raises(EOFError):
             im.seek(-1)
 
         with pytest.raises(EOFError):
             im.seek(42)
+
+
+def test_alpha_quality(tmp_path: Path) -> None:
+    with Image.open("Tests/images/transparent.png") as im:
+        first_frame = Image.new("L", im.size)
+
+        out = str(tmp_path / "temp.webp")
+        first_frame.save(out, save_all=True, append_images=[im])
+
+        out_quality = str(tmp_path / "quality.webp")
+        first_frame.save(
+            out_quality, save_all=True, append_images=[im], alpha_quality=50
+        )
+        with Image.open(out) as reloaded:
+            reloaded.seek(1)
+            with Image.open(out_quality) as reloaded_quality:
+                reloaded_quality.seek(1)
+                assert reloaded.tobytes() != reloaded_quality.tobytes()
