@@ -1,5 +1,7 @@
 from __future__ import annotations
+
 import os
+from pathlib import Path
 
 import pytest
 
@@ -19,7 +21,7 @@ message = "hello, world"
 pytestmark = skip_unless_feature("zlib")
 
 
-def save_font(request, tmp_path):
+def save_font(request: pytest.FixtureRequest, tmp_path: Path) -> str:
     with open(fontname, "rb") as test_file:
         font = PcfFontFile.PcfFontFile(test_file)
     assert isinstance(font, FontFile.FontFile)
@@ -28,7 +30,7 @@ def save_font(request, tmp_path):
 
     tempname = str(tmp_path / "temp.pil")
 
-    def delete_tempfile():
+    def delete_tempfile() -> None:
         try:
             os.remove(tempname[:-4] + ".pbm")
         except OSError:
@@ -46,11 +48,11 @@ def save_font(request, tmp_path):
     return tempname
 
 
-def test_sanity(request, tmp_path):
+def test_sanity(request: pytest.FixtureRequest, tmp_path: Path) -> None:
     save_font(request, tmp_path)
 
 
-def test_less_than_256_characters():
+def test_less_than_256_characters() -> None:
     with open("Tests/fonts/10x20-ISO8859-1-fewer-characters.pcf", "rb") as test_file:
         font = PcfFontFile.PcfFontFile(test_file)
     assert isinstance(font, FontFile.FontFile)
@@ -58,13 +60,13 @@ def test_less_than_256_characters():
     assert len([_f for _f in font.glyph if _f]) == 127
 
 
-def test_invalid_file():
+def test_invalid_file() -> None:
     with open("Tests/images/flower.jpg", "rb") as fp:
         with pytest.raises(SyntaxError):
             PcfFontFile.PcfFontFile(fp)
 
 
-def test_draw(request, tmp_path):
+def test_draw(request: pytest.FixtureRequest, tmp_path: Path) -> None:
     tempname = save_font(request, tmp_path)
     font = ImageFont.load(tempname)
     im = Image.new("L", (130, 30), "white")
@@ -73,7 +75,7 @@ def test_draw(request, tmp_path):
     assert_image_similar_tofile(im, "Tests/images/test_draw_pbm_target.png", 0)
 
 
-def test_textsize(request, tmp_path):
+def test_textsize(request: pytest.FixtureRequest, tmp_path: Path) -> None:
     tempname = save_font(request, tmp_path)
     font = ImageFont.load(tempname)
     for i in range(255):
@@ -89,7 +91,9 @@ def test_textsize(request, tmp_path):
         assert font.getbbox(msg) == (0, 0, len(msg) * 10, 20)
 
 
-def _test_high_characters(request, tmp_path, message):
+def _test_high_characters(
+    request: pytest.FixtureRequest, tmp_path: Path, message: str | bytes
+) -> None:
     tempname = save_font(request, tmp_path)
     font = ImageFont.load(tempname)
     im = Image.new("L", (750, 30), "white")
@@ -98,7 +102,7 @@ def _test_high_characters(request, tmp_path, message):
     assert_image_similar_tofile(im, "Tests/images/high_ascii_chars.png", 0)
 
 
-def test_high_characters(request, tmp_path):
+def test_high_characters(request: pytest.FixtureRequest, tmp_path: Path) -> None:
     message = "".join(chr(i + 1) for i in range(140, 232))
     _test_high_characters(request, tmp_path, message)
     # accept bytes instances.
