@@ -1,13 +1,17 @@
 from __future__ import annotations
+
 import datetime
 import os
 import re
 import shutil
+import sys
 from io import BytesIO
+from pathlib import Path
+from typing import Any, Literal, cast
 
 import pytest
 
-from PIL import Image, ImageMode, features
+from PIL import Image, ImageMode, ImageWin, features
 
 from .helper import (
     assert_image,
@@ -15,6 +19,7 @@ from .helper import (
     assert_image_similar,
     assert_image_similar_tofile,
     hopper,
+    is_pypy,
 )
 
 try:
@@ -31,7 +36,7 @@ SRGB = "Tests/icc/sRGB_IEC61966-2-1_black_scaled.icc"
 HAVE_PROFILE = os.path.exists(SRGB)
 
 
-def setup_module():
+def setup_module() -> None:
     try:
         from PIL import ImageCms
 
@@ -41,24 +46,27 @@ def setup_module():
         pytest.skip(str(v))
 
 
-def skip_missing():
+def skip_missing() -> None:
     if not HAVE_PROFILE:
         pytest.skip("SRGB profile not available")
 
 
-def test_sanity():
+def test_sanity() -> None:
     # basic smoke test.
     # this mostly follows the cms_test outline.
-
-    v = ImageCms.versions()  # should return four strings
+    with pytest.warns(DeprecationWarning):
+        v = ImageCms.versions()  # should return four strings
     assert v[0] == "1.0.0 pil"
     assert list(map(type, v)) == [str, str, str, str]
 
     # internal version number
-    assert re.search(r"\d+\.\d+(\.\d+)?$", features.version_module("littlecms2"))
+    version = features.version_module("littlecms2")
+    assert version is not None
+    assert re.search(r"\d+\.\d+(\.\d+)?$", version)
 
     skip_missing()
     i = ImageCms.profileToProfile(hopper(), SRGB, SRGB)
+    assert i is not None
     assert_image(i, "RGB", (128, 128))
 
     i = hopper()
@@ -67,30 +75,44 @@ def test_sanity():
 
     t = ImageCms.buildTransform(SRGB, SRGB, "RGB", "RGB")
     i = ImageCms.applyTransform(hopper(), t)
+    assert i is not None
     assert_image(i, "RGB", (128, 128))
 
     with hopper() as i:
         t = ImageCms.buildTransform(SRGB, SRGB, "RGB", "RGB")
         ImageCms.applyTransform(hopper(), t, inPlace=True)
+        assert i is not None
         assert_image(i, "RGB", (128, 128))
 
     p = ImageCms.createProfile("sRGB")
     o = ImageCms.getOpenProfile(SRGB)
     t = ImageCms.buildTransformFromOpenProfiles(p, o, "RGB", "RGB")
     i = ImageCms.applyTransform(hopper(), t)
+    assert i is not None
     assert_image(i, "RGB", (128, 128))
 
     t = ImageCms.buildProofTransform(SRGB, SRGB, SRGB, "RGB", "RGB")
     assert t.inputMode == "RGB"
     assert t.outputMode == "RGB"
     i = ImageCms.applyTransform(hopper(), t)
+    assert i is not None
     assert_image(i, "RGB", (128, 128))
 
     # test PointTransform convenience API
     hopper().point(t)
 
 
-def test_name():
+def test_flags() -> None:
+    assert ImageCms.Flags.NONE.value == 0
+    assert ImageCms.Flags.GRIDPOINTS(0) == ImageCms.Flags.NONE
+    assert ImageCms.Flags.GRIDPOINTS(256) == ImageCms.Flags.NONE
+
+    assert ImageCms.Flags.GRIDPOINTS(255) == (255 << 16)
+    assert ImageCms.Flags.GRIDPOINTS(-1) == ImageCms.Flags.GRIDPOINTS(255)
+    assert ImageCms.Flags.GRIDPOINTS(511) == ImageCms.Flags.GRIDPOINTS(255)
+
+
+def test_name() -> None:
     skip_missing()
     # get profile information for file
     assert (
@@ -99,7 +121,7 @@ def test_name():
     )
 
 
-def test_info():
+def test_info() -> None:
     skip_missing()
     assert ImageCms.getProfileInfo(SRGB).splitlines() == [
         "sRGB IEC61966-2-1 black scaled",
@@ -109,7 +131,7 @@ def test_info():
     ]
 
 
-def test_copyright():
+def test_copyright() -> None:
     skip_missing()
     assert (
         ImageCms.getProfileCopyright(SRGB).strip()
@@ -117,12 +139,12 @@ def test_copyright():
     )
 
 
-def test_manufacturer():
+def test_manufacturer() -> None:
     skip_missing()
     assert ImageCms.getProfileManufacturer(SRGB).strip() == ""
 
 
-def test_model():
+def test_model() -> None:
     skip_missing()
     assert (
         ImageCms.getProfileModel(SRGB).strip()
@@ -130,14 +152,14 @@ def test_model():
     )
 
 
-def test_description():
+def test_description() -> None:
     skip_missing()
     assert (
         ImageCms.getProfileDescription(SRGB).strip() == "sRGB IEC61966-2-1 black scaled"
     )
 
 
-def test_intent():
+def test_intent() -> None:
     skip_missing()
     assert ImageCms.getDefaultIntent(SRGB) == 0
     support = ImageCms.isIntentSupported(
@@ -146,7 +168,7 @@ def test_intent():
     assert support == 1
 
 
-def test_profile_object():
+def test_profile_object() -> None:
     # same, using profile object
     p = ImageCms.createProfile("sRGB")
     # assert ImageCms.getProfileName(p).strip() == "sRGB built-in - (lcms internal)"
@@ -159,7 +181,7 @@ def test_profile_object():
     assert support == 1
 
 
-def test_extensions():
+def test_extensions() -> None:
     # extensions
 
     with Image.open("Tests/images/rgb.jpg") as i:
@@ -170,7 +192,7 @@ def test_extensions():
     )
 
 
-def test_exceptions():
+def test_exceptions() -> None:
     # Test mode mismatch
     psRGB = ImageCms.createProfile("sRGB")
     pLab = ImageCms.createProfile("LAB")
@@ -187,53 +209,57 @@ def test_exceptions():
         ImageCms.buildTransform("foo", "bar", "RGB", "RGB")
 
     with pytest.raises(ImageCms.PyCMSError, match="Invalid type for Profile"):
-        ImageCms.getProfileName(None)
+        ImageCms.getProfileName(None)  # type: ignore[arg-type]
     skip_missing()
 
     # Python <= 3.9: "an integer is required (got type NoneType)"
     # Python > 3.9: "'NoneType' object cannot be interpreted as an integer"
     with pytest.raises(ImageCms.PyCMSError, match="integer"):
-        ImageCms.isIntentSupported(SRGB, None, None)
+        ImageCms.isIntentSupported(SRGB, None, None)  # type: ignore[arg-type]
 
 
-def test_display_profile():
+def test_display_profile() -> None:
     # try fetching the profile for the current display device
     ImageCms.get_display_profile()
 
+    if sys.platform == "win32":
+        ImageCms.get_display_profile(ImageWin.HDC(0))
+        ImageCms.get_display_profile(ImageWin.HWND(0))
 
-def test_lab_color_profile():
+
+def test_lab_color_profile() -> None:
     ImageCms.createProfile("LAB", 5000)
     ImageCms.createProfile("LAB", 6500)
 
 
-def test_unsupported_color_space():
+def test_unsupported_color_space() -> None:
     with pytest.raises(
         ImageCms.PyCMSError,
         match=re.escape(
             "Color space not supported for on-the-fly profile creation (unsupported)"
         ),
     ):
-        ImageCms.createProfile("unsupported")
+        ImageCms.createProfile("unsupported")  # type: ignore[arg-type]
 
 
-def test_invalid_color_temperature():
+def test_invalid_color_temperature() -> None:
     with pytest.raises(
         ImageCms.PyCMSError,
         match='Color temperature must be numeric, "invalid" not valid',
     ):
-        ImageCms.createProfile("LAB", "invalid")
+        ImageCms.createProfile("LAB", "invalid")  # type: ignore[arg-type]
 
 
 @pytest.mark.parametrize("flag", ("my string", -1))
-def test_invalid_flag(flag):
+def test_invalid_flag(flag: str | int) -> None:
     with hopper() as im:
         with pytest.raises(
             ImageCms.PyCMSError, match="flags must be an integer between 0 and "
         ):
-            ImageCms.profileToProfile(im, "foo", "bar", flags=flag)
+            ImageCms.profileToProfile(im, "foo", "bar", flags=flag)  # type: ignore[arg-type]
 
 
-def test_simple_lab():
+def test_simple_lab() -> None:
     i = Image.new("RGB", (10, 10), (128, 128, 128))
 
     psRGB = ImageCms.createProfile("sRGB")
@@ -241,7 +267,7 @@ def test_simple_lab():
     t = ImageCms.buildTransform(psRGB, pLab, "RGB", "LAB")
 
     i_lab = ImageCms.applyTransform(i, t)
-
+    assert i_lab is not None
     assert i_lab.mode == "LAB"
 
     k = i_lab.getpixel((0, 0))
@@ -257,7 +283,7 @@ def test_simple_lab():
     assert list(b_data) == [128] * 100
 
 
-def test_lab_color():
+def test_lab_color() -> None:
     psRGB = ImageCms.createProfile("sRGB")
     pLab = ImageCms.createProfile("LAB")
     t = ImageCms.buildTransform(psRGB, pLab, "RGB", "LAB")
@@ -265,6 +291,7 @@ def test_lab_color():
     # Need to add a type mapping for some PIL type to TYPE_Lab_8 in findLCMSType, and
     # have that mapping work back to a PIL mode (likely RGB).
     i = ImageCms.applyTransform(hopper(), t)
+    assert i is not None
     assert_image(i, "LAB", (128, 128))
 
     # i.save('temp.lab.tif')  # visually verified vs PS.
@@ -272,13 +299,14 @@ def test_lab_color():
     assert_image_similar_tofile(i, "Tests/images/hopper.Lab.tif", 3.5)
 
 
-def test_lab_srgb():
+def test_lab_srgb() -> None:
     psRGB = ImageCms.createProfile("sRGB")
     pLab = ImageCms.createProfile("LAB")
     t = ImageCms.buildTransform(pLab, psRGB, "LAB", "RGB")
 
     with Image.open("Tests/images/hopper.Lab.tif") as img:
         img_srgb = ImageCms.applyTransform(img, t)
+    assert img_srgb is not None
 
     # img_srgb.save('temp.srgb.tif') # visually verified vs ps.
 
@@ -289,7 +317,7 @@ def test_lab_srgb():
     assert "sRGB" in ImageCms.getProfileDescription(profile)
 
 
-def test_lab_roundtrip():
+def test_lab_roundtrip() -> None:
     # check to see if we're at least internally consistent.
     psRGB = ImageCms.createProfile("sRGB")
     pLab = ImageCms.createProfile("LAB")
@@ -298,15 +326,15 @@ def test_lab_roundtrip():
     t2 = ImageCms.buildTransform(pLab, psRGB, "LAB", "RGB")
 
     i = ImageCms.applyTransform(hopper(), t)
-
+    assert i is not None
     assert i.info["icc_profile"] == ImageCmsProfile(pLab).tobytes()
 
     out = ImageCms.applyTransform(i, t2)
-
+    assert out is not None
     assert_image_similar(hopper(), out, 2)
 
 
-def test_profile_tobytes():
+def test_profile_tobytes() -> None:
     with Image.open("Tests/images/rgb.jpg") as i:
         p = ImageCms.getOpenProfile(BytesIO(i.info["icc_profile"]))
 
@@ -318,24 +346,29 @@ def test_profile_tobytes():
     assert ImageCms.getProfileDescription(p) == ImageCms.getProfileDescription(p2)
 
 
-def test_extended_information():
+def test_extended_information() -> None:
     skip_missing()
     o = ImageCms.getOpenProfile(SRGB)
     p = o.profile
 
-    def assert_truncated_tuple_equal(tup1, tup2, digits=10):
+    def assert_truncated_tuple_equal(
+        tup1: tuple[Any, ...] | None, tup2: tuple[Any, ...], digits: int = 10
+    ) -> None:
         # Helper function to reduce precision of tuples of floats
         # recursively and then check equality.
         power = 10**digits
 
-        def truncate_tuple(tuple_or_float):
+        def truncate_tuple(tuple_value: tuple[Any, ...]) -> tuple[Any, ...]:
             return tuple(
-                truncate_tuple(val)
-                if isinstance(val, tuple)
-                else int(val * power) / power
-                for val in tuple_or_float
+                (
+                    truncate_tuple(val)
+                    if isinstance(val, tuple)
+                    else int(val * power) / power
+                )
+                for val in tuple_value
             )
 
+        assert tup1 is not None
         assert truncate_tuple(tup1) == truncate_tuple(tup2)
 
     assert p.attributes == 4294967296
@@ -465,7 +498,7 @@ def test_extended_information():
     assert p.xcolor_space == "RGB "
 
 
-def test_non_ascii_path(tmp_path):
+def test_non_ascii_path(tmp_path: Path) -> None:
     skip_missing()
     tempfile = str(tmp_path / ("temp_" + chr(128) + ".icc"))
     try:
@@ -478,20 +511,40 @@ def test_non_ascii_path(tmp_path):
     assert p.model == "IEC 61966-2-1 Default RGB Colour Space - sRGB"
 
 
-def test_profile_typesafety():
-    """Profile init type safety
-
-    prepatch, these would segfault, postpatch they should emit a typeerror
-    """
-
+def test_profile_typesafety() -> None:
+    # does not segfault
     with pytest.raises(TypeError, match="Invalid type for Profile"):
-        ImageCms.ImageCmsProfile(0).tobytes()
+        ImageCms.ImageCmsProfile(0)  # type: ignore[arg-type]
     with pytest.raises(TypeError, match="Invalid type for Profile"):
-        ImageCms.ImageCmsProfile(1).tobytes()
+        ImageCms.ImageCmsProfile(1)  # type: ignore[arg-type]
+
+    # also check core function
+    with pytest.raises(TypeError):
+        ImageCms.core.profile_tobytes(0)  # type: ignore[arg-type]
+    with pytest.raises(TypeError):
+        ImageCms.core.profile_tobytes(1)  # type: ignore[arg-type]
+
+    if not is_pypy():
+        # core profile should not be directly instantiable
+        with pytest.raises(TypeError):
+            ImageCms.core.CmsProfile()
+        with pytest.raises(TypeError):
+            ImageCms.core.CmsProfile(0)  # type: ignore[call-arg]
 
 
-def assert_aux_channel_preserved(mode, transform_in_place, preserved_channel):
-    def create_test_image():
+@pytest.mark.skipif(is_pypy(), reason="fails on PyPy")
+def test_transform_typesafety() -> None:
+    # core transform should not be directly instantiable
+    with pytest.raises(TypeError):
+        ImageCms.core.CmsTransform()
+    with pytest.raises(TypeError):
+        ImageCms.core.CmsTransform(0)  # type: ignore[call-arg]
+
+
+def assert_aux_channel_preserved(
+    mode: str, transform_in_place: bool, preserved_channel: str
+) -> None:
+    def create_test_image() -> Image.Image:
         # set up test image with something interesting in the tested aux channel.
         # fmt: off
         nine_grid_deltas = [
@@ -516,9 +569,9 @@ def assert_aux_channel_preserved(mode, transform_in_place, preserved_channel):
             for delta in nine_grid_deltas:
                 channel_data.paste(
                     channel_pattern,
-                    tuple(
-                        paste_offset[c] + delta[c] * channel_pattern.size[c]
-                        for c in range(2)
+                    (
+                        paste_offset[0] + delta[0] * channel_pattern.size[0],
+                        paste_offset[1] + delta[1] * channel_pattern.size[1],
                     ),
                 )
             chans.append(channel_data)
@@ -535,41 +588,43 @@ def assert_aux_channel_preserved(mode, transform_in_place, preserved_channel):
     )
 
     # apply transform
+    result_image: Image.Image | None
     if transform_in_place:
         ImageCms.applyTransform(source_image, t, inPlace=True)
         result_image = source_image
     else:
         result_image = ImageCms.applyTransform(source_image, t, inPlace=False)
+    assert result_image is not None
     result_image_aux = result_image.getchannel(preserved_channel)
 
     assert_image_equal(source_image_aux, result_image_aux)
 
 
-def test_preserve_auxiliary_channels_rgba():
+def test_preserve_auxiliary_channels_rgba() -> None:
     assert_aux_channel_preserved(
         mode="RGBA", transform_in_place=False, preserved_channel="A"
     )
 
 
-def test_preserve_auxiliary_channels_rgba_in_place():
+def test_preserve_auxiliary_channels_rgba_in_place() -> None:
     assert_aux_channel_preserved(
         mode="RGBA", transform_in_place=True, preserved_channel="A"
     )
 
 
-def test_preserve_auxiliary_channels_rgbx():
+def test_preserve_auxiliary_channels_rgbx() -> None:
     assert_aux_channel_preserved(
         mode="RGBX", transform_in_place=False, preserved_channel="X"
     )
 
 
-def test_preserve_auxiliary_channels_rgbx_in_place():
+def test_preserve_auxiliary_channels_rgbx_in_place() -> None:
     assert_aux_channel_preserved(
         mode="RGBX", transform_in_place=True, preserved_channel="X"
     )
 
 
-def test_auxiliary_channels_isolated():
+def test_auxiliary_channels_isolated() -> None:
     # test data in aux channels does not affect non-aux channels
     aux_channel_formats = [
         # format, profile, color-only format, source test image
@@ -585,8 +640,10 @@ def test_auxiliary_channels_isolated():
                     continue
 
                 # convert with and without AUX data, test colors are equal
-                source_profile = ImageCms.createProfile(src_format[1])
-                destination_profile = ImageCms.createProfile(dst_format[1])
+                src_colorSpace = cast(Literal["LAB", "XYZ", "sRGB"], src_format[1])
+                source_profile = ImageCms.createProfile(src_colorSpace)
+                dst_colorSpace = cast(Literal["LAB", "XYZ", "sRGB"], dst_format[1])
+                destination_profile = ImageCms.createProfile(dst_colorSpace)
                 source_image = src_format[3]
                 test_transform = ImageCms.buildTransform(
                     source_profile,
@@ -596,6 +653,7 @@ def test_auxiliary_channels_isolated():
                 )
 
                 # test conversion from aux-ful source
+                test_image: Image.Image | None
                 if transform_in_place:
                     test_image = source_image.copy()
                     ImageCms.applyTransform(test_image, test_transform, inPlace=True)
@@ -603,6 +661,7 @@ def test_auxiliary_channels_isolated():
                     test_image = ImageCms.applyTransform(
                         source_image, test_transform, inPlace=False
                     )
+                assert test_image is not None
 
                 # reference conversion from aux-less source
                 reference_transform = ImageCms.buildTransform(
@@ -614,12 +673,18 @@ def test_auxiliary_channels_isolated():
                 reference_image = ImageCms.applyTransform(
                     source_image.convert(src_format[2]), reference_transform
                 )
-
+                assert reference_image is not None
                 assert_image_equal(test_image.convert(dst_format[2]), reference_image)
 
 
+def test_long_modes() -> None:
+    p = ImageCms.getOpenProfile("Tests/icc/sGrey-v2-nano.icc")
+    with pytest.warns(DeprecationWarning):
+        ImageCms.buildTransform(p, p, "ABCDEFGHI", "ABCDEFGHI")
+
+
 @pytest.mark.parametrize("mode", ("RGB", "RGBA", "RGBX"))
-def test_rgb_lab(mode):
+def test_rgb_lab(mode: str) -> None:
     im = Image.new(mode, (1, 1))
     converted_im = im.convert("LAB")
     assert converted_im.getpixel((0, 0)) == (0, 128, 128)
@@ -627,3 +692,18 @@ def test_rgb_lab(mode):
     im = Image.new("LAB", (1, 1), (255, 0, 0))
     converted_im = im.convert(mode)
     assert converted_im.getpixel((0, 0))[:3] == (0, 255, 255)
+
+
+def test_deprecation() -> None:
+    with pytest.warns(DeprecationWarning):
+        assert ImageCms.DESCRIPTION.strip().startswith("pyCMS")
+    with pytest.warns(DeprecationWarning):
+        assert ImageCms.VERSION == "1.0.0 pil"
+    with pytest.warns(DeprecationWarning):
+        assert isinstance(ImageCms.FLAGS, dict)
+
+    profile = ImageCmsProfile(ImageCms.createProfile("sRGB"))
+    with pytest.warns(DeprecationWarning):
+        ImageCms.ImageCmsTransform(profile, profile, "RGBA;16B", "RGB")
+    with pytest.warns(DeprecationWarning):
+        ImageCms.ImageCmsTransform(profile, profile, "RGB", "RGBA;16B")
