@@ -1,10 +1,13 @@
 from __future__ import annotations
+
 import contextlib
 import os.path
+from typing import Sequence
 
 import pytest
 
 from PIL import Image, ImageColor, ImageDraw, ImageFont, features
+from PIL._typing import Coords
 
 from .helper import (
     assert_image_equal,
@@ -46,7 +49,7 @@ KITE_POINTS = (
 )
 
 
-def test_sanity():
+def test_sanity() -> None:
     im = hopper("RGB").copy()
 
     draw = ImageDraw.ImageDraw(im)
@@ -58,13 +61,13 @@ def test_sanity():
     draw.rectangle(list(range(4)))
 
 
-def test_valueerror():
+def test_valueerror() -> None:
     with Image.open("Tests/images/chi.gif") as im:
         draw = ImageDraw.Draw(im)
         draw.line((0, 0), fill=(0, 0, 0))
 
 
-def test_mode_mismatch():
+def test_mode_mismatch() -> None:
     im = hopper("RGB").copy()
 
     with pytest.raises(ValueError):
@@ -73,7 +76,7 @@ def test_mode_mismatch():
 
 @pytest.mark.parametrize("bbox", BBOX)
 @pytest.mark.parametrize("start, end", ((0, 180), (0.5, 180.4)))
-def test_arc(bbox, start, end):
+def test_arc(bbox: Coords, start: float, end: float) -> None:
     # Arrange
     im = Image.new("RGB", (W, H))
     draw = ImageDraw.Draw(im)
@@ -86,7 +89,7 @@ def test_arc(bbox, start, end):
 
 
 @pytest.mark.parametrize("bbox", BBOX)
-def test_arc_end_le_start(bbox):
+def test_arc_end_le_start(bbox: Coords) -> None:
     # Arrange
     im = Image.new("RGB", (W, H))
     draw = ImageDraw.Draw(im)
@@ -101,7 +104,7 @@ def test_arc_end_le_start(bbox):
 
 
 @pytest.mark.parametrize("bbox", BBOX)
-def test_arc_no_loops(bbox):
+def test_arc_no_loops(bbox: Coords) -> None:
     # No need to go in loops
     # Arrange
     im = Image.new("RGB", (W, H))
@@ -117,7 +120,7 @@ def test_arc_no_loops(bbox):
 
 
 @pytest.mark.parametrize("bbox", BBOX)
-def test_arc_width(bbox):
+def test_arc_width(bbox: Coords) -> None:
     # Arrange
     im = Image.new("RGB", (W, H))
     draw = ImageDraw.Draw(im)
@@ -130,7 +133,7 @@ def test_arc_width(bbox):
 
 
 @pytest.mark.parametrize("bbox", BBOX)
-def test_arc_width_pieslice_large(bbox):
+def test_arc_width_pieslice_large(bbox: Coords) -> None:
     # Tests an arc with a large enough width that it is a pieslice
     # Arrange
     im = Image.new("RGB", (W, H))
@@ -144,7 +147,7 @@ def test_arc_width_pieslice_large(bbox):
 
 
 @pytest.mark.parametrize("bbox", BBOX)
-def test_arc_width_fill(bbox):
+def test_arc_width_fill(bbox: Coords) -> None:
     # Arrange
     im = Image.new("RGB", (W, H))
     draw = ImageDraw.Draw(im)
@@ -157,7 +160,7 @@ def test_arc_width_fill(bbox):
 
 
 @pytest.mark.parametrize("bbox", BBOX)
-def test_arc_width_non_whole_angle(bbox):
+def test_arc_width_non_whole_angle(bbox: Coords) -> None:
     # Arrange
     im = Image.new("RGB", (W, H))
     draw = ImageDraw.Draw(im)
@@ -170,7 +173,7 @@ def test_arc_width_non_whole_angle(bbox):
     assert_image_similar_tofile(im, expected, 1)
 
 
-def test_arc_high():
+def test_arc_high() -> None:
     # Arrange
     im = Image.new("RGB", (200, 200))
     draw = ImageDraw.Draw(im)
@@ -183,7 +186,7 @@ def test_arc_high():
     assert_image_equal_tofile(im, "Tests/images/imagedraw_arc_high.png")
 
 
-def test_bitmap():
+def test_bitmap() -> None:
     # Arrange
     im = Image.new("RGB", (W, H))
     draw = ImageDraw.Draw(im)
@@ -199,7 +202,7 @@ def test_bitmap():
 
 @pytest.mark.parametrize("mode", ("RGB", "L"))
 @pytest.mark.parametrize("bbox", BBOX)
-def test_chord(mode, bbox):
+def test_chord(mode: str, bbox: Coords) -> None:
     # Arrange
     im = Image.new(mode, (W, H))
     draw = ImageDraw.Draw(im)
@@ -213,7 +216,7 @@ def test_chord(mode, bbox):
 
 
 @pytest.mark.parametrize("bbox", BBOX)
-def test_chord_width(bbox):
+def test_chord_width(bbox: Coords) -> None:
     # Arrange
     im = Image.new("RGB", (W, H))
     draw = ImageDraw.Draw(im)
@@ -226,7 +229,7 @@ def test_chord_width(bbox):
 
 
 @pytest.mark.parametrize("bbox", BBOX)
-def test_chord_width_fill(bbox):
+def test_chord_width_fill(bbox: Coords) -> None:
     # Arrange
     im = Image.new("RGB", (W, H))
     draw = ImageDraw.Draw(im)
@@ -239,7 +242,7 @@ def test_chord_width_fill(bbox):
 
 
 @pytest.mark.parametrize("bbox", BBOX)
-def test_chord_zero_width(bbox):
+def test_chord_zero_width(bbox: Coords) -> None:
     # Arrange
     im = Image.new("RGB", (W, H))
     draw = ImageDraw.Draw(im)
@@ -251,7 +254,7 @@ def test_chord_zero_width(bbox):
     assert_image_equal_tofile(im, "Tests/images/imagedraw_chord_zero_width.png")
 
 
-def test_chord_too_fat():
+def test_chord_too_fat() -> None:
     # Arrange
     im = Image.new("RGB", (100, 100))
     draw = ImageDraw.Draw(im)
@@ -263,9 +266,24 @@ def test_chord_too_fat():
     assert_image_equal_tofile(im, "Tests/images/imagedraw_chord_too_fat.png")
 
 
+@pytest.mark.parametrize("mode", ("RGB", "L"))
+@pytest.mark.parametrize("xy", ((W / 2, H / 2), [W / 2, H / 2]))
+def test_circle(mode: str, xy: Sequence[float]) -> None:
+    # Arrange
+    im = Image.new(mode, (W, H))
+    draw = ImageDraw.Draw(im)
+    expected = f"Tests/images/imagedraw_ellipse_{mode}.png"
+
+    # Act
+    draw.circle(xy, 25, fill="green", outline="blue")
+
+    # Assert
+    assert_image_similar_tofile(im, expected, 1)
+
+
 @pytest.mark.parametrize("mode", ("RGB", "L"))
 @pytest.mark.parametrize("bbox", BBOX)
-def test_ellipse(mode, bbox):
+def test_ellipse(mode: str, bbox: Coords) -> None:
     # Arrange
     im = Image.new(mode, (W, H))
     draw = ImageDraw.Draw(im)
@@ -279,7 +297,7 @@ def test_ellipse(mode, bbox):
 
 
 @pytest.mark.parametrize("bbox", BBOX)
-def test_ellipse_translucent(bbox):
+def test_ellipse_translucent(bbox: Coords) -> None:
     # Arrange
     im = Image.new("RGB", (W, H))
     draw = ImageDraw.Draw(im, "RGBA")
@@ -292,7 +310,7 @@ def test_ellipse_translucent(bbox):
     assert_image_similar_tofile(im, expected, 1)
 
 
-def test_ellipse_edge():
+def test_ellipse_edge() -> None:
     # Arrange
     im = Image.new("RGB", (W, H))
     draw = ImageDraw.Draw(im)
@@ -304,7 +322,7 @@ def test_ellipse_edge():
     assert_image_similar_tofile(im, "Tests/images/imagedraw_ellipse_edge.png", 1)
 
 
-def test_ellipse_symmetric():
+def test_ellipse_symmetric() -> None:
     for width, bbox in (
         (100, (24, 24, 75, 75)),
         (101, (25, 25, 75, 75)),
@@ -316,7 +334,7 @@ def test_ellipse_symmetric():
 
 
 @pytest.mark.parametrize("bbox", BBOX)
-def test_ellipse_width(bbox):
+def test_ellipse_width(bbox: Coords) -> None:
     # Arrange
     im = Image.new("RGB", (W, H))
     draw = ImageDraw.Draw(im)
@@ -328,7 +346,7 @@ def test_ellipse_width(bbox):
     assert_image_similar_tofile(im, "Tests/images/imagedraw_ellipse_width.png", 1)
 
 
-def test_ellipse_width_large():
+def test_ellipse_width_large() -> None:
     # Arrange
     im = Image.new("RGB", (500, 500))
     draw = ImageDraw.Draw(im)
@@ -341,7 +359,7 @@ def test_ellipse_width_large():
 
 
 @pytest.mark.parametrize("bbox", BBOX)
-def test_ellipse_width_fill(bbox):
+def test_ellipse_width_fill(bbox: Coords) -> None:
     # Arrange
     im = Image.new("RGB", (W, H))
     draw = ImageDraw.Draw(im)
@@ -354,7 +372,7 @@ def test_ellipse_width_fill(bbox):
 
 
 @pytest.mark.parametrize("bbox", BBOX)
-def test_ellipse_zero_width(bbox):
+def test_ellipse_zero_width(bbox: Coords) -> None:
     # Arrange
     im = Image.new("RGB", (W, H))
     draw = ImageDraw.Draw(im)
@@ -366,7 +384,7 @@ def test_ellipse_zero_width(bbox):
     assert_image_equal_tofile(im, "Tests/images/imagedraw_ellipse_zero_width.png")
 
 
-def ellipse_various_sizes_helper(filled):
+def ellipse_various_sizes_helper(filled: bool) -> Image.Image:
     ellipse_sizes = range(32)
     image_size = sum(ellipse_sizes) + len(ellipse_sizes) + 1
     im = Image.new("RGB", (image_size, image_size))
@@ -393,13 +411,13 @@ def ellipse_various_sizes_helper(filled):
     return im
 
 
-def test_ellipse_various_sizes():
+def test_ellipse_various_sizes() -> None:
     im = ellipse_various_sizes_helper(False)
 
     assert_image_equal_tofile(im, "Tests/images/imagedraw_ellipse_various_sizes.png")
 
 
-def test_ellipse_various_sizes_filled():
+def test_ellipse_various_sizes_filled() -> None:
     im = ellipse_various_sizes_helper(True)
 
     assert_image_equal_tofile(
@@ -408,7 +426,7 @@ def test_ellipse_various_sizes_filled():
 
 
 @pytest.mark.parametrize("points", POINTS)
-def test_line(points):
+def test_line(points: Coords) -> None:
     # Arrange
     im = Image.new("RGB", (W, H))
     draw = ImageDraw.Draw(im)
@@ -420,7 +438,7 @@ def test_line(points):
     assert_image_equal_tofile(im, "Tests/images/imagedraw_line.png")
 
 
-def test_shape1():
+def test_shape1() -> None:
     # Arrange
     im = Image.new("RGB", (100, 100), "white")
     draw = ImageDraw.Draw(im)
@@ -430,6 +448,7 @@ def test_shape1():
     x3, y3 = 95, 5
 
     # Act
+    assert ImageDraw.Outline is not None
     s = ImageDraw.Outline()
     s.move(x0, y0)
     s.curve(x1, y1, x2, y2, x3, y3)
@@ -441,7 +460,7 @@ def test_shape1():
     assert_image_equal_tofile(im, "Tests/images/imagedraw_shape1.png")
 
 
-def test_shape2():
+def test_shape2() -> None:
     # Arrange
     im = Image.new("RGB", (100, 100), "white")
     draw = ImageDraw.Draw(im)
@@ -451,6 +470,7 @@ def test_shape2():
     x3, y3 = 5, 95
 
     # Act
+    assert ImageDraw.Outline is not None
     s = ImageDraw.Outline()
     s.move(x0, y0)
     s.curve(x1, y1, x2, y2, x3, y3)
@@ -462,13 +482,14 @@ def test_shape2():
     assert_image_equal_tofile(im, "Tests/images/imagedraw_shape2.png")
 
 
-def test_transform():
+def test_transform() -> None:
     # Arrange
     im = Image.new("RGB", (100, 100), "white")
     expected = im.copy()
     draw = ImageDraw.Draw(im)
 
     # Act
+    assert ImageDraw.Outline is not None
     s = ImageDraw.Outline()
     s.line(0, 0)
     s.transform((0, 0, 0, 0, 0, 0))
@@ -481,7 +502,7 @@ def test_transform():
 
 @pytest.mark.parametrize("bbox", BBOX)
 @pytest.mark.parametrize("start, end", ((-92, 46), (-92.2, 46.2)))
-def test_pieslice(bbox, start, end):
+def test_pieslice(bbox: Coords, start: float, end: float) -> None:
     # Arrange
     im = Image.new("RGB", (W, H))
     draw = ImageDraw.Draw(im)
@@ -494,7 +515,7 @@ def test_pieslice(bbox, start, end):
 
 
 @pytest.mark.parametrize("bbox", BBOX)
-def test_pieslice_width(bbox):
+def test_pieslice_width(bbox: Coords) -> None:
     # Arrange
     im = Image.new("RGB", (W, H))
     draw = ImageDraw.Draw(im)
@@ -507,7 +528,7 @@ def test_pieslice_width(bbox):
 
 
 @pytest.mark.parametrize("bbox", BBOX)
-def test_pieslice_width_fill(bbox):
+def test_pieslice_width_fill(bbox: Coords) -> None:
     # Arrange
     im = Image.new("RGB", (W, H))
     draw = ImageDraw.Draw(im)
@@ -521,7 +542,7 @@ def test_pieslice_width_fill(bbox):
 
 
 @pytest.mark.parametrize("bbox", BBOX)
-def test_pieslice_zero_width(bbox):
+def test_pieslice_zero_width(bbox: Coords) -> None:
     # Arrange
     im = Image.new("RGB", (W, H))
     draw = ImageDraw.Draw(im)
@@ -533,7 +554,7 @@ def test_pieslice_zero_width(bbox):
     assert_image_equal_tofile(im, "Tests/images/imagedraw_pieslice_zero_width.png")
 
 
-def test_pieslice_wide():
+def test_pieslice_wide() -> None:
     # Arrange
     im = Image.new("RGB", (200, 100))
     draw = ImageDraw.Draw(im)
@@ -545,7 +566,7 @@ def test_pieslice_wide():
     assert_image_equal_tofile(im, "Tests/images/imagedraw_pieslice_wide.png")
 
 
-def test_pieslice_no_spikes():
+def test_pieslice_no_spikes() -> None:
     im = Image.new("RGB", (161, 161), "white")
     draw = ImageDraw.Draw(im)
     cxs = (
@@ -576,7 +597,7 @@ def test_pieslice_no_spikes():
 
 
 @pytest.mark.parametrize("points", POINTS)
-def test_point(points):
+def test_point(points: Coords) -> None:
     # Arrange
     im = Image.new("RGB", (W, H))
     draw = ImageDraw.Draw(im)
@@ -588,7 +609,7 @@ def test_point(points):
     assert_image_equal_tofile(im, "Tests/images/imagedraw_point.png")
 
 
-def test_point_I16():
+def test_point_I16() -> None:
     # Arrange
     im = Image.new("I;16", (1, 1))
     draw = ImageDraw.Draw(im)
@@ -601,7 +622,7 @@ def test_point_I16():
 
 
 @pytest.mark.parametrize("points", POINTS)
-def test_polygon(points):
+def test_polygon(points: Coords) -> None:
     # Arrange
     im = Image.new("RGB", (W, H))
     draw = ImageDraw.Draw(im)
@@ -613,9 +634,24 @@ def test_polygon(points):
     assert_image_equal_tofile(im, "Tests/images/imagedraw_polygon.png")
 
 
+@pytest.mark.parametrize("points", POINTS)
+def test_polygon_width_I16(points: Coords) -> None:
+    # Arrange
+    im = Image.new("I;16", (W, H))
+    draw = ImageDraw.Draw(im)
+
+    # Act
+    draw.polygon(points, outline=0xFFFF, width=2)
+
+    # Assert
+    assert_image_equal_tofile(im, "Tests/images/imagedraw_polygon_width_I.tiff")
+
+
 @pytest.mark.parametrize("mode", ("RGB", "L"))
 @pytest.mark.parametrize("kite_points", KITE_POINTS)
-def test_polygon_kite(mode, kite_points):
+def test_polygon_kite(
+    mode: str, kite_points: tuple[tuple[int, int], ...] | list[tuple[int, int]]
+) -> None:
     # Test drawing lines of different gradients (dx>dy, dy>dx) and
     # vertical (dx==0) and horizontal (dy==0) lines
     # Arrange
@@ -630,7 +666,7 @@ def test_polygon_kite(mode, kite_points):
     assert_image_equal_tofile(im, expected)
 
 
-def test_polygon_1px_high():
+def test_polygon_1px_high() -> None:
     # Test drawing a 1px high polygon
     # Arrange
     im = Image.new("RGB", (3, 3))
@@ -644,7 +680,7 @@ def test_polygon_1px_high():
     assert_image_equal_tofile(im, expected)
 
 
-def test_polygon_1px_high_translucent():
+def test_polygon_1px_high_translucent() -> None:
     # Test drawing a translucent 1px high polygon
     # Arrange
     im = Image.new("RGB", (4, 3))
@@ -658,7 +694,7 @@ def test_polygon_1px_high_translucent():
     assert_image_equal_tofile(im, expected)
 
 
-def test_polygon_translucent():
+def test_polygon_translucent() -> None:
     # Arrange
     im = Image.new("RGB", (W, H))
     draw = ImageDraw.Draw(im, "RGBA")
@@ -672,7 +708,7 @@ def test_polygon_translucent():
 
 
 @pytest.mark.parametrize("bbox", BBOX)
-def test_rectangle(bbox):
+def test_rectangle(bbox: Coords) -> None:
     # Arrange
     im = Image.new("RGB", (W, H))
     draw = ImageDraw.Draw(im)
@@ -684,7 +720,7 @@ def test_rectangle(bbox):
     assert_image_equal_tofile(im, "Tests/images/imagedraw_rectangle.png")
 
 
-def test_big_rectangle():
+def test_big_rectangle() -> None:
     # Test drawing a rectangle bigger than the image
     # Arrange
     im = Image.new("RGB", (W, H))
@@ -699,7 +735,7 @@ def test_big_rectangle():
 
 
 @pytest.mark.parametrize("bbox", BBOX)
-def test_rectangle_width(bbox):
+def test_rectangle_width(bbox: Coords) -> None:
     # Arrange
     im = Image.new("RGB", (W, H))
     draw = ImageDraw.Draw(im)
@@ -713,7 +749,7 @@ def test_rectangle_width(bbox):
 
 
 @pytest.mark.parametrize("bbox", BBOX)
-def test_rectangle_width_fill(bbox):
+def test_rectangle_width_fill(bbox: Coords) -> None:
     # Arrange
     im = Image.new("RGB", (W, H))
     draw = ImageDraw.Draw(im)
@@ -727,7 +763,7 @@ def test_rectangle_width_fill(bbox):
 
 
 @pytest.mark.parametrize("bbox", BBOX)
-def test_rectangle_zero_width(bbox):
+def test_rectangle_zero_width(bbox: Coords) -> None:
     # Arrange
     im = Image.new("RGB", (W, H))
     draw = ImageDraw.Draw(im)
@@ -740,7 +776,7 @@ def test_rectangle_zero_width(bbox):
 
 
 @pytest.mark.parametrize("bbox", BBOX)
-def test_rectangle_I16(bbox):
+def test_rectangle_I16(bbox: Coords) -> None:
     # Arrange
     im = Image.new("I;16", (W, H))
     draw = ImageDraw.Draw(im)
@@ -749,11 +785,11 @@ def test_rectangle_I16(bbox):
     draw.rectangle(bbox, outline=0xFFFF)
 
     # Assert
-    assert_image_equal_tofile(im.convert("I"), "Tests/images/imagedraw_rectangle_I.png")
+    assert_image_equal_tofile(im, "Tests/images/imagedraw_rectangle_I.tiff")
 
 
 @pytest.mark.parametrize("bbox", BBOX)
-def test_rectangle_translucent_outline(bbox):
+def test_rectangle_translucent_outline(bbox: Coords) -> None:
     # Arrange
     im = Image.new("RGB", (W, H))
     draw = ImageDraw.Draw(im, "RGBA")
@@ -771,7 +807,13 @@ def test_rectangle_translucent_outline(bbox):
     "xy",
     [(10, 20, 190, 180), ([10, 20], [190, 180]), ((10, 20), (190, 180))],
 )
-def test_rounded_rectangle(xy):
+def test_rounded_rectangle(
+    xy: (
+        tuple[int, int, int, int]
+        | tuple[list[int]]
+        | tuple[tuple[int, int], tuple[int, int]]
+    )
+) -> None:
     # Arrange
     im = Image.new("RGB", (200, 200))
     draw = ImageDraw.Draw(im)
@@ -787,7 +829,9 @@ def test_rounded_rectangle(xy):
 @pytest.mark.parametrize("top_right", (True, False))
 @pytest.mark.parametrize("bottom_right", (True, False))
 @pytest.mark.parametrize("bottom_left", (True, False))
-def test_rounded_rectangle_corners(top_left, top_right, bottom_right, bottom_left):
+def test_rounded_rectangle_corners(
+    top_left: bool, top_right: bool, bottom_right: bool, bottom_left: bool
+) -> None:
     corners = (top_left, top_right, bottom_right, bottom_left)
 
     # Arrange
@@ -821,7 +865,9 @@ def test_rounded_rectangle_corners(top_left, top_right, bottom_right, bottom_lef
         ((10, 20, 190, 181), 85, "height"),
     ],
 )
-def test_rounded_rectangle_non_integer_radius(xy, radius, type):
+def test_rounded_rectangle_non_integer_radius(
+    xy: tuple[int, int, int, int], radius: float, type: str
+) -> None:
     # Arrange
     im = Image.new("RGB", (200, 200))
     draw = ImageDraw.Draw(im)
@@ -837,7 +883,7 @@ def test_rounded_rectangle_non_integer_radius(xy, radius, type):
 
 
 @pytest.mark.parametrize("bbox", BBOX)
-def test_rounded_rectangle_zero_radius(bbox):
+def test_rounded_rectangle_zero_radius(bbox: Coords) -> None:
     # Arrange
     im = Image.new("RGB", (W, H))
     draw = ImageDraw.Draw(im)
@@ -854,12 +900,16 @@ def test_rounded_rectangle_zero_radius(bbox):
     [
         ((20, 10, 80, 90), "x"),
         ((20, 10, 81, 90), "x_odd"),
+        ((20, 10, 81.1, 90), "x_odd"),
         ((10, 20, 90, 80), "y"),
         ((10, 20, 90, 81), "y_odd"),
+        ((10, 20, 90, 81.1), "y_odd"),
         ((20, 20, 80, 80), "both"),
     ],
 )
-def test_rounded_rectangle_translucent(xy, suffix):
+def test_rounded_rectangle_translucent(
+    xy: tuple[int, int, int, int], suffix: str
+) -> None:
     # Arrange
     im = Image.new("RGB", (W, H))
     draw = ImageDraw.Draw(im, "RGBA")
@@ -876,10 +926,15 @@ def test_rounded_rectangle_translucent(xy, suffix):
 
 
 @pytest.mark.parametrize("bbox", BBOX)
-def test_floodfill(bbox):
+def test_floodfill(bbox: Coords) -> None:
     red = ImageColor.getrgb("red")
 
-    for mode, value in [("L", 1), ("RGBA", (255, 0, 0, 0)), ("RGB", red)]:
+    mode_values: list[tuple[str, int | tuple[int, ...]]] = [
+        ("L", 1),
+        ("RGBA", (255, 0, 0, 0)),
+        ("RGB", red),
+    ]
+    for mode, value in mode_values:
         # Arrange
         im = Image.new(mode, (W, H))
         draw = ImageDraw.Draw(im)
@@ -909,7 +964,7 @@ def test_floodfill(bbox):
 
 
 @pytest.mark.parametrize("bbox", BBOX)
-def test_floodfill_border(bbox):
+def test_floodfill_border(bbox: Coords) -> None:
     # floodfill() is experimental
 
     # Arrange
@@ -931,7 +986,7 @@ def test_floodfill_border(bbox):
 
 
 @pytest.mark.parametrize("bbox", BBOX)
-def test_floodfill_thresh(bbox):
+def test_floodfill_thresh(bbox: Coords) -> None:
     # floodfill() is experimental
 
     # Arrange
@@ -947,7 +1002,7 @@ def test_floodfill_thresh(bbox):
     assert_image_equal_tofile(im, "Tests/images/imagedraw_floodfill2.png")
 
 
-def test_floodfill_not_negative():
+def test_floodfill_not_negative() -> None:
     # floodfill() is experimental
     # Test that floodfill does not extend into negative coordinates
 
@@ -965,8 +1020,11 @@ def test_floodfill_not_negative():
 
 
 def create_base_image_draw(
-    size, mode=DEFAULT_MODE, background1=WHITE, background2=GRAY
-):
+    size: tuple[int, int],
+    mode: str = DEFAULT_MODE,
+    background1: tuple[int, int, int] = WHITE,
+    background2: tuple[int, int, int] = GRAY,
+) -> tuple[Image.Image, ImageDraw.ImageDraw]:
     img = Image.new(mode, size, background1)
     for x in range(0, size[0]):
         for y in range(0, size[1]):
@@ -975,7 +1033,7 @@ def create_base_image_draw(
     return img, ImageDraw.Draw(img)
 
 
-def test_square():
+def test_square() -> None:
     expected = os.path.join(IMAGES_PATH, "square.png")
     img, draw = create_base_image_draw((10, 10))
     draw.polygon([(2, 2), (2, 7), (7, 7), (7, 2)], BLACK)
@@ -988,7 +1046,7 @@ def test_square():
     assert_image_equal_tofile(img, expected, "square as normal rectangle failed")
 
 
-def test_triangle_right():
+def test_triangle_right() -> None:
     img, draw = create_base_image_draw((20, 20))
     draw.polygon([(3, 5), (17, 5), (10, 12)], BLACK)
     assert_image_equal_tofile(
@@ -1000,7 +1058,7 @@ def test_triangle_right():
     "fill, suffix",
     ((BLACK, "width"), (None, "width_no_fill")),
 )
-def test_triangle_right_width(fill, suffix):
+def test_triangle_right_width(fill: tuple[int, int, int] | None, suffix: str) -> None:
     img, draw = create_base_image_draw((100, 100))
     draw.polygon([(15, 25), (85, 25), (50, 60)], fill, WHITE, width=5)
     assert_image_equal_tofile(
@@ -1008,7 +1066,7 @@ def test_triangle_right_width(fill, suffix):
     )
 
 
-def test_line_horizontal():
+def test_line_horizontal() -> None:
     img, draw = create_base_image_draw((20, 20))
     draw.line((5, 5, 14, 5), BLACK, 2)
     assert_image_equal_tofile(
@@ -1046,8 +1104,8 @@ def test_line_horizontal():
     )
 
 
-def test_line_h_s1_w2():
-    pytest.skip("failing")
+@pytest.mark.xfail(reason="failing test")
+def test_line_h_s1_w2() -> None:
     img, draw = create_base_image_draw((20, 20))
     draw.line((5, 5, 14, 6), BLACK, 2)
     assert_image_equal_tofile(
@@ -1057,7 +1115,7 @@ def test_line_h_s1_w2():
     )
 
 
-def test_line_vertical():
+def test_line_vertical() -> None:
     img, draw = create_base_image_draw((20, 20))
     draw.line((5, 5, 5, 14), BLACK, 2)
     assert_image_equal_tofile(
@@ -1103,7 +1161,7 @@ def test_line_vertical():
     )
 
 
-def test_line_oblique_45():
+def test_line_oblique_45() -> None:
     expected = os.path.join(IMAGES_PATH, "line_oblique_45_w3px_a.png")
     img, draw = create_base_image_draw((20, 20))
     draw.line((5, 5, 14, 14), BLACK, 3)
@@ -1125,7 +1183,7 @@ def test_line_oblique_45():
     )
 
 
-def test_wide_line_dot():
+def test_wide_line_dot() -> None:
     # Test drawing a wide "line" from one point to another just draws a single point
     # Arrange
     im = Image.new("RGB", (W, H))
@@ -1138,7 +1196,7 @@ def test_wide_line_dot():
     assert_image_similar_tofile(im, "Tests/images/imagedraw_wide_line_dot.png", 1)
 
 
-def test_wide_line_larger_than_int():
+def test_wide_line_larger_than_int() -> None:
     # Arrange
     im = Image.new("RGB", (W, H))
     draw = ImageDraw.Draw(im)
@@ -1232,7 +1290,7 @@ def test_wide_line_larger_than_int():
         ],
     ],
 )
-def test_line_joint(xy):
+def test_line_joint(xy: list[tuple[int, int]] | tuple[int, ...] | list[int]) -> None:
     im = Image.new("RGB", (500, 325))
     draw = ImageDraw.Draw(im)
 
@@ -1243,7 +1301,7 @@ def test_line_joint(xy):
     assert_image_similar_tofile(im, "Tests/images/imagedraw_line_joint_curve.png", 3)
 
 
-def test_textsize_empty_string():
+def test_textsize_empty_string() -> None:
     # https://github.com/python-pillow/Pillow/issues/2783
     # Arrange
     im = Image.new("RGB", (W, H))
@@ -1259,7 +1317,7 @@ def test_textsize_empty_string():
 
 
 @skip_unless_feature("freetype2")
-def test_textbbox_stroke():
+def test_textbbox_stroke() -> None:
     # Arrange
     im = Image.new("RGB", (W, H))
     draw = ImageDraw.Draw(im)
@@ -1273,7 +1331,7 @@ def test_textbbox_stroke():
 
 
 @skip_unless_feature("freetype2")
-def test_stroke():
+def test_stroke() -> None:
     for suffix, stroke_fill in {"same": None, "different": "#0f0"}.items():
         # Arrange
         im = Image.new("RGB", (120, 130))
@@ -1290,7 +1348,7 @@ def test_stroke():
 
 
 @skip_unless_feature("freetype2")
-def test_stroke_descender():
+def test_stroke_descender() -> None:
     # Arrange
     im = Image.new("RGB", (120, 130))
     draw = ImageDraw.Draw(im)
@@ -1304,7 +1362,7 @@ def test_stroke_descender():
 
 
 @skip_unless_feature("freetype2")
-def test_split_word():
+def test_split_word() -> None:
     # Arrange
     im = Image.new("RGB", (230, 55))
     expected = im.copy()
@@ -1325,7 +1383,7 @@ def test_split_word():
 
 
 @skip_unless_feature("freetype2")
-def test_stroke_multiline():
+def test_stroke_multiline() -> None:
     # Arrange
     im = Image.new("RGB", (100, 250))
     draw = ImageDraw.Draw(im)
@@ -1341,7 +1399,7 @@ def test_stroke_multiline():
 
 
 @skip_unless_feature("freetype2")
-def test_setting_default_font():
+def test_setting_default_font() -> None:
     # Arrange
     im = Image.new("RGB", (100, 250))
     draw = ImageDraw.Draw(im)
@@ -1358,7 +1416,7 @@ def test_setting_default_font():
         assert isinstance(draw.getfont(), ImageFont.load_default().__class__)
 
 
-def test_default_font_size():
+def test_default_font_size() -> None:
     freetype_support = features.check_module("freetype2")
     text = "Default font at a specific size."
 
@@ -1385,13 +1443,14 @@ def test_default_font_size():
 
 
 @pytest.mark.parametrize("bbox", BBOX)
-def test_same_color_outline(bbox):
+def test_same_color_outline(bbox: Coords) -> None:
     # Prepare shape
     x0, y0 = 5, 5
     x1, y1 = 5, 50
     x2, y2 = 95, 50
     x3, y3 = 95, 5
 
+    assert ImageDraw.Outline is not None
     s = ImageDraw.Outline()
     s.move(x0, y0)
     s.curve(x1, y1, x2, y2, x3, y3)
@@ -1399,7 +1458,8 @@ def test_same_color_outline(bbox):
 
     # Begin
     for mode in ["RGB", "L"]:
-        for fill, outline in [["red", None], ["red", "red"], ["red", "#f00"]]:
+        fill = "red"
+        for outline in [None, "red", "#f00"]:
             for operation, args in {
                 "chord": [bbox, 0, 180],
                 "ellipse": [bbox],
@@ -1414,6 +1474,7 @@ def test_same_color_outline(bbox):
 
                 # Act
                 draw_method = getattr(draw, operation)
+                assert isinstance(args, list)
                 args += [fill, outline]
                 draw_method(*args)
 
@@ -1428,15 +1489,20 @@ def test_same_color_outline(bbox):
         (4, "square", {}),
         (8, "regular_octagon", {}),
         (4, "square_rotate_45", {"rotation": 45}),
-        (3, "triangle_width", {"width": 5, "outline": "yellow"}),
+        (3, "triangle_width", {"outline": "yellow", "width": 5}),
     ],
 )
-def test_draw_regular_polygon(n_sides, polygon_name, args):
+def test_draw_regular_polygon(
+    n_sides: int, polygon_name: str, args: dict[str, int | str]
+) -> None:
     im = Image.new("RGBA", size=(W, H), color=(255, 0, 0, 0))
     filename = f"Tests/images/imagedraw_{polygon_name}.png"
     draw = ImageDraw.Draw(im)
     bounding_circle = ((W // 2, H // 2), 25)
-    draw.regular_polygon(bounding_circle, n_sides, fill="red", **args)
+    rotation = int(args.get("rotation", 0))
+    outline = args.get("outline")
+    width = int(args.get("width", 1))
+    draw.regular_polygon(bounding_circle, n_sides, rotation, "red", outline, width)
     assert_image_equal_tofile(im, filename)
 
 
@@ -1468,7 +1534,9 @@ def test_draw_regular_polygon(n_sides, polygon_name, args):
         ),
     ],
 )
-def test_compute_regular_polygon_vertices(n_sides, expected_vertices):
+def test_compute_regular_polygon_vertices(
+    n_sides: int, expected_vertices: list[tuple[float, float]]
+) -> None:
     bounding_circle = (W // 2, H // 2, 25)
     vertices = ImageDraw._compute_regular_polygon_vertices(bounding_circle, n_sides, 0)
     assert vertices == expected_vertices
@@ -1479,7 +1547,7 @@ def test_compute_regular_polygon_vertices(n_sides, expected_vertices):
     [
         (None, (50, 50, 25), 0, TypeError, "n_sides should be an int"),
         (1, (50, 50, 25), 0, ValueError, "n_sides should be an int > 2"),
-        (3, 50, 0, TypeError, "bounding_circle should be a tuple"),
+        (3, 50, 0, TypeError, "bounding_circle should be a sequence"),
         (
             3,
             (50, 50, 100, 100),
@@ -1519,14 +1587,18 @@ def test_compute_regular_polygon_vertices(n_sides, expected_vertices):
     ],
 )
 def test_compute_regular_polygon_vertices_input_error_handling(
-    n_sides, bounding_circle, rotation, expected_error, error_message
-):
+    n_sides: int,
+    bounding_circle: int | tuple[int | tuple[int] | str, ...],
+    rotation: int | str,
+    expected_error: type[Exception],
+    error_message: str,
+) -> None:
     with pytest.raises(expected_error) as e:
-        ImageDraw._compute_regular_polygon_vertices(bounding_circle, n_sides, rotation)
+        ImageDraw._compute_regular_polygon_vertices(bounding_circle, n_sides, rotation)  # type: ignore[arg-type]
     assert str(e.value) == error_message
 
 
-def test_continuous_horizontal_edges_polygon():
+def test_continuous_horizontal_edges_polygon() -> None:
     xy = [
         (2, 6),
         (6, 6),
@@ -1545,7 +1617,7 @@ def test_continuous_horizontal_edges_polygon():
     )
 
 
-def test_discontiguous_corners_polygon():
+def test_discontiguous_corners_polygon() -> None:
     img, draw = create_base_image_draw((84, 68))
     draw.polygon(((1, 21), (34, 4), (71, 1), (38, 18)), BLACK)
     draw.polygon(((71, 44), (38, 27), (1, 24)), BLACK)
@@ -1557,7 +1629,7 @@ def test_discontiguous_corners_polygon():
     assert_image_similar_tofile(img, expected, 1)
 
 
-def test_polygon2():
+def test_polygon2() -> None:
     im = Image.new("RGB", (W, H))
     draw = ImageDraw.Draw(im)
     draw.polygon([(18, 30), (19, 31), (18, 30), (85, 30), (60, 72)], "red")
@@ -1566,7 +1638,7 @@ def test_polygon2():
 
 
 @pytest.mark.parametrize("xy", ((1, 1, 0, 1), (1, 1, 1, 0)))
-def test_incorrectly_ordered_coordinates(xy):
+def test_incorrectly_ordered_coordinates(xy: tuple[int, int, int, int]) -> None:
     im = Image.new("RGB", (W, H))
     draw = ImageDraw.Draw(im)
     with pytest.raises(ValueError):
@@ -1581,3 +1653,8 @@ def test_incorrectly_ordered_coordinates(xy):
         draw.rectangle(xy)
     with pytest.raises(ValueError):
         draw.rounded_rectangle(xy)
+
+
+def test_getdraw() -> None:
+    with pytest.warns(DeprecationWarning):
+        ImageDraw.getdraw(None, [])
