@@ -15,7 +15,7 @@
 #
 
 ##
-# Image plugin for the Spider image format.  This format is is used
+# Image plugin for the Spider image format. This format is used
 # by the SPIDER software, in processing image data from electron
 # microscopy and tomography.
 ##
@@ -32,14 +32,17 @@
 # Details about the Spider image format:
 # https://spider.wadsworth.org/spider_doc/spider/docs/image_doc.html
 #
+from __future__ import annotations
+
 import os
 import struct
 import sys
+from typing import IO, TYPE_CHECKING, Any, Tuple, cast
 
-from PIL import Image, ImageFile
+from . import Image, ImageFile
 
 
-def isInt(f):
+def isInt(f: Any) -> int:
     try:
         i = int(f)
         if f - i == 0:
@@ -59,7 +62,7 @@ iforms = [1, 3, -11, -12, -21, -22]
 # otherwise returns 0
 
 
-def isSpiderHeader(t):
+def isSpiderHeader(t: tuple[float, ...]) -> int:
     h = (99,) + t  # add 1 value so can use spider header index start=1
     # header values 1,2,5,12,13,22,23 should be integers
     for i in [1, 2, 5, 12, 13, 22, 23]:
@@ -79,7 +82,7 @@ def isSpiderHeader(t):
     return labbyt
 
 
-def isSpiderImage(filename):
+def isSpiderImage(filename: str) -> int:
     with open(filename, "rb") as fp:
         f = fp.read(92)  # read 23 * 4 bytes
     t = struct.unpack(">23f", f)  # try big-endian first
@@ -91,12 +94,11 @@ def isSpiderImage(filename):
 
 
 class SpiderImageFile(ImageFile.ImageFile):
-
     format = "SPIDER"
     format_description = "Spider 2D image"
     _close_exclusive_fp_after_loading = False
 
-    def _open(self):
+    def _open(self) -> None:
         # check header
         n = 27 * 4  # read 27 float values
         f = self.fp.read(n)
@@ -110,14 +112,17 @@ class SpiderImageFile(ImageFile.ImageFile):
                 t = struct.unpack("<27f", f)  # little-endian
                 hdrlen = isSpiderHeader(t)
             if hdrlen == 0:
-                raise SyntaxError("not a valid Spider file")
+                msg = "not a valid Spider file"
+                raise SyntaxError(msg)
         except struct.error as e:
-            raise SyntaxError("not a valid Spider file") from e
+            msg = "not a valid Spider file"
+            raise SyntaxError(msg) from e
 
         h = (99,) + t  # add 1 value : spider header index starts at 1
         iform = int(h[5])
         if iform != 1:
-            raise SyntaxError("not a Spider 2D image")
+            msg = "not a Spider 2D image"
+            raise SyntaxError(msg)
 
         self._size = int(h[12]), int(h[2])  # size in pixels (width, height)
         self.istack = int(h[24])
@@ -140,75 +145,74 @@ class SpiderImageFile(ImageFile.ImageFile):
             offset = hdrlen + self.stkoffset
             self.istack = 2  # So Image knows it's still a stack
         else:
-            raise SyntaxError("inconsistent stack header values")
+            msg = "inconsistent stack header values"
+            raise SyntaxError(msg)
 
         if self.bigendian:
             self.rawmode = "F;32BF"
         else:
             self.rawmode = "F;32F"
-        self.mode = "F"
+        self._mode = "F"
 
         self.tile = [("raw", (0, 0) + self.size, offset, (self.rawmode, 0, 1))]
-        self.__fp = self.fp  # FIXME: hack
+        self._fp = self.fp  # FIXME: hack
 
     @property
-    def n_frames(self):
+    def n_frames(self) -> int:
         return self._nimages
 
     @property
-    def is_animated(self):
+    def is_animated(self) -> bool:
         return self._nimages > 1
 
     # 1st image index is zero (although SPIDER imgnumber starts at 1)
-    def tell(self):
+    def tell(self) -> int:
         if self.imgnumber < 1:
             return 0
         else:
             return self.imgnumber - 1
 
-    def seek(self, frame):
+    def seek(self, frame: int) -> None:
         if self.istack == 0:
-            raise EOFError("attempt to seek in a non-stack file")
+            msg = "attempt to seek in a non-stack file"
+            raise EOFError(msg)
         if not self._seek_check(frame):
             return
         self.stkoffset = self.hdrlen + frame * (self.hdrlen + self.imgbytes)
-        self.fp = self.__fp
+        self.fp = self._fp
         self.fp.seek(self.stkoffset)
         self._open()
 
     # returns a byte image after rescaling to 0..255
-    def convert2byte(self, depth=255):
-        (minimum, maximum) = self.getextrema()
-        m = 1
+    def convert2byte(self, depth: int = 255) -> Image.Image:
+        extrema = self.getextrema()
+        assert isinstance(extrema[0], float)
+        minimum, maximum = cast(Tuple[float, float], extrema)
+        m: float = 1
         if maximum != minimum:
             m = depth / (maximum - minimum)
         b = -m * minimum
-        return self.point(lambda i, m=m, b=b: i * m + b).convert("L")
+        return self.point(lambda i: i * m + b).convert("L")
+
+    if TYPE_CHECKING:
+        from . import ImageTk
 
     # returns a ImageTk.PhotoImage object, after rescaling to 0..255
-    def tkPhotoImage(self):
-        from PIL import ImageTk
+    def tkPhotoImage(self) -> ImageTk.PhotoImage:
+        from . import ImageTk
 
         return ImageTk.PhotoImage(self.convert2byte(), palette=256)
 
-    def _close__fp(self):
-        try:
-            if self.__fp != self.fp:
-                self.__fp.close()
-        except AttributeError:
-            pass
-        finally:
-            self.__fp = None
-
 
 # --------------------------------------------------------------------
 # Image series
 
+
 # given a list of filenames, return a list of images
-def loadImageSeries(filelist=None):
+def loadImageSeries(filelist: list[str] | None = None) -> list[SpiderImageFile] | None:
     """create a list of :py:class:`~PIL.Image.Image` objects for use in a montage"""
     if filelist is None or len(filelist) < 1:
-        return
+        return None
 
     imglist = []
     for img in filelist:
@@ -220,7 +224,7 @@ def loadImageSeries(filelist=None):
                 im = im.convert2byte()
         except Exception:
             if not isSpiderImage(img):
-                print(img + " is not a Spider image file")
+                print(f"{img} is not a Spider image file")
             continue
         im.info["filename"] = img
         imglist.append(im)
@@ -231,24 +235,23 @@ def loadImageSeries(filelist=None):
 # For saving images in Spider format
 
 
-def makeSpiderHeader(im):
+def makeSpiderHeader(im: Image.Image) -> list[bytes]:
     nsam, nrow = im.size
     lenbyt = nsam * 4  # There are labrec records in the header
     labrec = int(1024 / lenbyt)
     if 1024 % lenbyt != 0:
         labrec += 1
     labbyt = labrec * lenbyt
-    hdr = []
     nvalues = int(labbyt / 4)
-    for i in range(nvalues):
-        hdr.append(0.0)
-
-    if len(hdr) < 23:
+    if nvalues < 23:
         return []
 
+    hdr = [0.0] * nvalues
+
     # NB these are Fortran indices
     hdr[1] = 1.0  # nslice (=1 for an image)
     hdr[2] = float(nrow)  # number of rows per slice
+    hdr[3] = float(nrow)  # number of records in the image
     hdr[5] = 1.0  # iform for 2D image
     hdr[12] = float(nsam)  # number of pixels per line
     hdr[13] = float(labrec)  # number of records in file header
@@ -259,19 +262,17 @@ def makeSpiderHeader(im):
     hdr = hdr[1:]
     hdr.append(0.0)
     # pack binary data into a string
-    hdrstr = []
-    for v in hdr:
-        hdrstr.append(struct.pack("f", v))
-    return hdrstr
+    return [struct.pack("f", v) for v in hdr]
 
 
-def _save(im, fp, filename):
+def _save(im: Image.Image, fp: IO[bytes], filename: str | bytes) -> None:
     if im.mode[0] != "F":
         im = im.convert("F")
 
     hdr = makeSpiderHeader(im)
     if len(hdr) < 256:
-        raise OSError("Error creating Spider header")
+        msg = "Error creating Spider header"
+        raise OSError(msg)
 
     # write the SPIDER header
     fp.writelines(hdr)
@@ -280,9 +281,10 @@ def _save(im, fp, filename):
     ImageFile._save(im, fp, [("raw", (0, 0) + im.size, 0, (rawmode, 0, 1))])
 
 
-def _save_spider(im, fp, filename):
+def _save_spider(im: Image.Image, fp: IO[bytes], filename: str | bytes) -> None:
     # get the filename extension and register it with Image
-    ext = os.path.splitext(filename)[1]
+    filename_ext = os.path.splitext(filename)[1]
+    ext = filename_ext.decode() if isinstance(filename_ext, bytes) else filename_ext
     Image.register_extension(SpiderImageFile.format, ext)
     _save(im, fp, filename)
 
@@ -294,7 +296,6 @@ Image.register_open(SpiderImageFile.format, SpiderImageFile)
 Image.register_save(SpiderImageFile.format, _save_spider)
 
 if __name__ == "__main__":
-
     if len(sys.argv) < 2:
         print("Syntax: python3 SpiderImagePlugin.py [infile] [outfile]")
         sys.exit()
@@ -305,10 +306,10 @@ if __name__ == "__main__":
         sys.exit()
 
     with Image.open(filename) as im:
-        print("image: " + str(im))
-        print("format: " + str(im.format))
-        print("size: " + str(im.size))
-        print("mode: " + str(im.mode))
+        print(f"image: {im}")
+        print(f"format: {im.format}")
+        print(f"size: {im.size}")
+        print(f"mode: {im.mode}")
         print("max, min: ", end=" ")
         print(im.getextrema())
 
@@ -316,7 +317,7 @@ if __name__ == "__main__":
             outfile = sys.argv[2]
 
             # perform some image operation
-            im = im.transpose(Image.FLIP_LEFT_RIGHT)
+            im = im.transpose(Image.Transpose.FLIP_LEFT_RIGHT)
             print(
                 f"saving a flipped version of {os.path.basename(filename)} "
                 f"as {outfile} "
