@@ -251,18 +251,18 @@ static struct PyGetSetDef getsetters[] = {
 
 static PyTypeObject ImagingDisplayType = {
     PyVarObject_HEAD_INIT(NULL, 0) "ImagingDisplay", /*tp_name*/
-    sizeof(ImagingDisplayObject),                    /*tp_size*/
+    sizeof(ImagingDisplayObject),                    /*tp_basicsize*/
     0,                                               /*tp_itemsize*/
     /* methods */
     (destructor)_delete, /*tp_dealloc*/
-    0,                   /*tp_print*/
+    0,                   /*tp_vectorcall_offset*/
     0,                   /*tp_getattr*/
     0,                   /*tp_setattr*/
-    0,                   /*tp_compare*/
+    0,                   /*tp_as_async*/
     0,                   /*tp_repr*/
-    0,                   /*tp_as_number */
-    0,                   /*tp_as_sequence */
-    0,                   /*tp_as_mapping */
+    0,                   /*tp_as_number*/
+    0,                   /*tp_as_sequence*/
+    0,                   /*tp_as_mapping*/
     0,                   /*tp_hash*/
     0,                   /*tp_call*/
     0,                   /*tp_str*/
@@ -427,7 +427,6 @@ error:
 
 PyObject *
 PyImaging_GrabClipboardWin32(PyObject *self, PyObject *args) {
-    int clip;
     HANDLE handle = NULL;
     int size;
     void *data;
@@ -619,7 +618,7 @@ windowCallback(HWND wnd, UINT message, WPARAM wParam, LPARAM lParam) {
     if (callback) {
         /* restore thread state */
         PyEval_SaveThread();
-        PyThreadState_Swap(threadstate);
+        PyThreadState_Swap(current_threadstate);
     }
 
     return status;
@@ -717,7 +716,7 @@ PyImaging_DrawWmf(PyObject *self, PyObject *args) {
     HDC dc;
     RECT rect;
     PyObject *buffer = NULL;
-    char *ptr;
+    void *ptr;
 
     char *data;
     Py_ssize_t datasize;
