@@ -183,9 +183,9 @@ j2ku_gray_i(
                 UINT16 *row = (UINT16 *)im->image[y0 + y] + x0;
                 for (x = 0; x < w; ++x) {
                     UINT16 pixel = j2ku_shift(offset + *data++, shift);
-                    #ifdef WORDS_BIGENDIAN
-                        pixel = (pixel >> 8) | (pixel << 8);
-                    #endif
+#ifdef WORDS_BIGENDIAN
+                    pixel = (pixel >> 8) | (pixel << 8);
+#endif
                     *row++ = pixel;
                 }
             }
@@ -615,6 +615,8 @@ j2ku_sycca_rgba(
 
 static const struct j2k_decode_unpacker j2k_unpackers[] = {
     {"L", OPJ_CLRSPC_GRAY, 1, 0, j2ku_gray_l},
+    {"P", OPJ_CLRSPC_SRGB, 1, 0, j2ku_gray_l},
+    {"PA", OPJ_CLRSPC_SRGB, 2, 0, j2ku_graya_la},
     {"I;16", OPJ_CLRSPC_GRAY, 1, 0, j2ku_gray_i},
     {"I;16B", OPJ_CLRSPC_GRAY, 1, 0, j2ku_gray_i},
     {"LA", OPJ_CLRSPC_GRAY, 2, 0, j2ku_graya_la},
@@ -630,6 +632,7 @@ static const struct j2k_decode_unpacker j2k_unpackers[] = {
     {"RGBA", OPJ_CLRSPC_SYCC, 3, 1, j2ku_sycc_rgb},
     {"RGBA", OPJ_CLRSPC_SRGB, 4, 1, j2ku_srgba_rgba},
     {"RGBA", OPJ_CLRSPC_SYCC, 4, 1, j2ku_sycca_rgba},
+    {"CMYK", OPJ_CLRSPC_CMYK, 4, 1, j2ku_srgba_rgba},
 };
 
 /* -------------------------------------------------------------------- */
@@ -775,7 +778,7 @@ j2k_decode_entry(Imaging im, ImagingCodecState state) {
                         color_space = OPJ_CLRSPC_SYCC;
                         break;
                 }
-            break;
+                break;
         }
     }
 
@@ -861,7 +864,7 @@ j2k_decode_entry(Imaging im, ImagingCodecState state) {
          a, and then a malicious file could have a smaller tile_bytes
         */
 
-        for (n=0; n < tile_info.nb_comps; n++) {
+        for (n = 0; n < tile_info.nb_comps; n++) {
             // see csize /acsize calcs
             int csize = (image->comps[n].prec + 7) >> 3;
             csize = (csize == 3) ? 4 : csize;
