@@ -57,7 +57,7 @@ alloc_array(Py_ssize_t count) {
     if ((unsigned long long)count > (SIZE_MAX / (2 * sizeof(double))) - 1) {
         return ImagingError_MemoryError();
     }
-    xy = calloc(2 * count * sizeof(double) + 1, sizeof(double));
+    xy = calloc(2 * count + 1, sizeof(double));
     if (!xy) {
         ImagingError_MemoryError();
     }
@@ -162,42 +162,37 @@ PyPath_Flatten(PyObject *data, double **pxy) {
         return -1;
     }
 
+#define assign_item_to_array(op, decref)                                \
+    if (PyFloat_Check(op)) {                                            \
+        xy[j++] = PyFloat_AS_DOUBLE(op);                                \
+    } else if (PyLong_Check(op)) {                                      \
+        xy[j++] = (float)PyLong_AS_LONG(op);                            \
+    } else if (PyNumber_Check(op)) {                                    \
+        xy[j++] = PyFloat_AsDouble(op);                                 \
+    } else if (PyArg_ParseTuple(op, "dd", &x, &y)) {                    \
+        xy[j++] = x;                                                    \
+        xy[j++] = y;                                                    \
+    } else {                                                            \
+        PyErr_SetString(PyExc_ValueError, "incorrect coordinate type"); \
+        if (decref) {                                                   \
+            Py_DECREF(op);                                              \
+        }                                                               \
+        free(xy);                                                       \
+        return -1;                                                      \
+    }
+
     /* Copy table to path array */
     if (PyList_Check(data)) {
         for (i = 0; i < n; i++) {
             double x, y;
             PyObject *op = PyList_GET_ITEM(data, i);
-            if (PyFloat_Check(op)) {
-                xy[j++] = PyFloat_AS_DOUBLE(op);
-            } else if (PyLong_Check(op)) {
-                xy[j++] = (float)PyLong_AS_LONG(op);
-            } else if (PyNumber_Check(op)) {
-                xy[j++] = PyFloat_AsDouble(op);
-            } else if (PyArg_ParseTuple(op, "dd", &x, &y)) {
-                xy[j++] = x;
-                xy[j++] = y;
-            } else {
-                free(xy);
-                return -1;
-            }
+            assign_item_to_array(op, 0);
         }
     } else if (PyTuple_Check(data)) {
         for (i = 0; i < n; i++) {
             double x, y;
             PyObject *op = PyTuple_GET_ITEM(data, i);
-            if (PyFloat_Check(op)) {
-                xy[j++] = PyFloat_AS_DOUBLE(op);
-            } else if (PyLong_Check(op)) {
-                xy[j++] = (float)PyLong_AS_LONG(op);
-            } else if (PyNumber_Check(op)) {
-                xy[j++] = PyFloat_AsDouble(op);
-            } else if (PyArg_ParseTuple(op, "dd", &x, &y)) {
-                xy[j++] = x;
-                xy[j++] = y;
-            } else {
-                free(xy);
-                return -1;
-            }
+            assign_item_to_array(op, 0);
         }
     } else {
         for (i = 0; i < n; i++) {
@@ -213,20 +208,7 @@ PyPath_Flatten(PyObject *data, double **pxy) {
                     return -1;
                 }
             }
-            if (PyFloat_Check(op)) {
-                xy[j++] = PyFloat_AS_DOUBLE(op);
-            } else if (PyLong_Check(op)) {
-                xy[j++] = (float)PyLong_AS_LONG(op);
-            } else if (PyNumber_Check(op)) {
-                xy[j++] = PyFloat_AsDouble(op);
-            } else if (PyArg_ParseTuple(op, "dd", &x, &y)) {
-                xy[j++] = x;
-                xy[j++] = y;
-            } else {
-                Py_DECREF(op);
-                free(xy);
-                return -1;
-            }
+            assign_item_to_array(op, 1);
             Py_DECREF(op);
         }
     }
@@ -457,6 +439,9 @@ path_tolist(PyPathObject *self, PyObject *args) {
 
     if (flat) {
         list = PyList_New(self->count * 2);
+        if (list == NULL) {
+            return NULL;
+        }
         for (i = 0; i < self->count * 2; i++) {
             PyObject *item;
             item = PyFloat_FromDouble(self->xy[i]);
@@ -467,6 +452,9 @@ path_tolist(PyPathObject *self, PyObject *args) {
         }
     } else {
         list = PyList_New(self->count);
+        if (list == NULL) {
+            return NULL;
+        }
         for (i = 0; i < self->count; i++) {
             PyObject *item;
             item = Py_BuildValue("dd", self->xy[i + i], self->xy[i + i + 1]);
@@ -595,18 +583,18 @@ static PyMappingMethods path_as_mapping = {
 
 static PyTypeObject PyPathType = {
     PyVarObject_HEAD_INIT(NULL, 0) "Path", /*tp_name*/
-    sizeof(PyPathObject),                  /*tp_size*/
+    sizeof(PyPathObject),                  /*tp_basicsize*/
     0,                                     /*tp_itemsize*/
     /* methods */
     (destructor)path_dealloc, /*tp_dealloc*/
-    0,                        /*tp_print*/
+    0,                        /*tp_vectorcall_offset*/
     0,                        /*tp_getattr*/
     0,                        /*tp_setattr*/
-    0,                        /*tp_compare*/
+    0,                        /*tp_as_async*/
     0,                        /*tp_repr*/
-    0,                        /*tp_as_number */
-    &path_as_sequence,        /*tp_as_sequence */
-    &path_as_mapping,         /*tp_as_mapping */
+    0,                        /*tp_as_number*/
+    &path_as_sequence,        /*tp_as_sequence*/
+    &path_as_mapping,         /*tp_as_mapping*/
     0,                        /*tp_hash*/
     0,                        /*tp_call*/
     0,                        /*tp_str*/
